@@ -1792,7 +1792,7 @@ long cm_BPlusDirCreateEntry(cm_dirOp_t * op, clientchar_t * entry, cm_fid_t * cf
     bplus_create_entry++;
 
     insert(op->scp->dirBplus, key, data);
-    
+
     if (!cm_Is8Dot3(entry)) {
         cm_dirFid_t dfid;
         clientchar_t wshortName[13];
@@ -1999,7 +1999,7 @@ int cm_BPlusDirFoo(struct cm_scache *scp, struct cm_dirEntry *dep,
     dataT  data;
     normchar_t *normalized_name=NULL;
 
-    cm_SetFid(&data.fid, scp->fid.cell, scp->fid.volume, 
+    cm_SetFid(&data.fid, scp->fid.cell, scp->fid.volume,
               ntohl(dep->fid.vnode), ntohl(dep->fid.unique));
     data.cname = NULL;
     data.fsname = NULL;
@@ -2014,7 +2014,7 @@ int cm_BPlusDirFoo(struct cm_scache *scp, struct cm_dirEntry *dep,
 #endif
         return 0;
     }
-  
+
     data.cname = cm_FsStringToClientStringAlloc(dep->name, -1, NULL);
     if (data.cname == NULL) {
 #ifdef DEBUG
@@ -2024,7 +2024,7 @@ int cm_BPlusDirFoo(struct cm_scache *scp, struct cm_dirEntry *dep,
     }
     data.fsname = cm_FsStrDup(dep->name);
     data.shortform = FALSE;
-     
+
     /* the Write lock is held in cm_BPlusDirBuildTree() */
     insert(scp->dirBplus, key, data);
 
@@ -2040,11 +2040,11 @@ int cm_BPlusDirFoo(struct cm_scache *scp, struct cm_dirEntry *dep,
         key.name = wshortName;
         data.cname = cm_FsStringToClientStringAlloc(dep->name, -1, NULL);
         if (data.cname) {
-        data.fsname = cm_FsStrDup(dep->name);
-        data.shortform = TRUE;
-  
-        insert(scp->dirBplus, key, data);
-    }
+            data.fsname = cm_FsStrDup(dep->name);
+            data.shortform = TRUE;
+
+            insert(scp->dirBplus, key, data);
+        }
     }
 
     if (normalized_name)
@@ -2468,6 +2468,31 @@ cm_BPlusDirNextEnumEntry(cm_direnum_t *enump, cm_direnum_entry_t **entrypp)
     }
 }
 
+long
+cm_BPlusDirPeekNextEnumEntry(cm_direnum_t *enump, cm_direnum_entry_t **entrypp)
+{	
+    if (enump == NULL || entrypp == NULL || enump->next >= enump->count) {
+	if (entrypp)
+	    *entrypp = NULL;
+	osi_Log0(afsd_logp, "cm_BPlusDirPeekNextEnumEntry invalid input");
+	return CM_ERROR_INVAL;
+    }
+
+    if (enump->fetchStatus && 
+        !(enump->entry[enump->next].flags & CM_DIRENUM_FLAG_GOT_STATUS))
+        cm_BPlusDirEnumBulkStatNext(enump);
+
+    *entrypp = &enump->entry[enump->next];
+    if ( enump->next == enump->count ) {
+	osi_Log0(afsd_logp, "cm_BPlusDirPeekNextEnumEntry STOPNOW");
+	return CM_ERROR_STOPNOW;
+    }
+    else {
+	osi_Log0(afsd_logp, "cm_BPlusDirPeekNextEnumEntry SUCCESS");
+	return 0;
+    }
+}
+
 long 
 cm_BPlusDirFreeEnumeration(cm_direnum_t *enump)
 {
