@@ -397,15 +397,21 @@ void cm_fakeSCacheInit(int newFile)
 {
     if ( newFile ) {
         memset(&cm_data.fakeSCache, 0, sizeof(cm_scache_t));
+        cm_data.fakeSCache.magic = CM_SCACHE_MAGIC;
         cm_data.fakeSCache.cbServerp = (struct cm_server *)(-1);
+        cm_data.fakeSCache.cbExpires = (time_t)-1;
         /* can leave clientModTime at 0 */
         cm_data.fakeSCache.fileType = CM_SCACHETYPE_FILE;
         cm_data.fakeSCache.unixModeBits = 0777;
         cm_data.fakeSCache.length.LowPart = 1000;
         cm_data.fakeSCache.linkCount = 1;
         cm_data.fakeSCache.refCount = 1;
+        cm_data.fakeSCache.serverLock = -1;
+        cm_data.fakeSCache.dataVersion = CM_SCACHE_VERSION_BAD;
     }
     lock_InitializeRWLock(&cm_data.fakeSCache.rw, "cm_scache_t rw", LOCK_HIERARCHY_SCACHE);
+    lock_InitializeRWLock(&cm_data.fakeSCache.bufCreateLock, "cm_scache_t bufCreateLock", LOCK_HIERARCHY_SCACHE_BUFCREATE);
+    lock_InitializeRWLock(&cm_data.fakeSCache.dirlock, "cm_scache_t dirlock", LOCK_HIERARCHY_SCACHE_DIRLOCK);
 }
 
 long
@@ -686,7 +692,8 @@ long cm_GetSCache(cm_fid_t *fidp, cm_scache_t **outScpp, cm_user_t *userp,
         
     hash = CM_SCACHE_HASH(fidp);
         
-    osi_assertx(fidp->cell != 0, "unassigned cell value");
+    if (fidp->cell == 0)
+        return CM_ERROR_INVAL;
 
 #ifdef AFS_FREELANCE_CLIENT
     special = (fidp->cell==AFS_FAKE_ROOT_CELL_ID && 
@@ -1507,13 +1514,20 @@ void cm_MergeStatus(cm_scache_t *dscp,
     // yj: i want to create some fake status for the /afs directory and the
     // entries under that directory
 #ifdef AFS_FREELANCE_CLIENT
-    if (cm_freelanceEnabled && scp == cm_data.rootSCachep) {
-        osi_Log0(afsd_logp,"cm_MergeStatus Freelance cm_data.rootSCachep");
+    if (cm_freelanceEnabled && scp->fid.cell==AFS_FAKE_ROOT_CELL_ID &&
+         scp->fid.volume==AFS_FAKE_ROOT_VOL_ID) {
+        if (scp == cm_data.rootSCachep) {
+            osi_Log0(afsd_logp,"cm_MergeStatus Freelance cm_data.rootSCachep");
+            statusp->FileType = CM_SCACHETYPE_DIRECTORY;
+            statusp->Length = cm_fakeDirSize;
+            statusp->Length_hi = 0;
+        } else {
+            statusp->FileType = scp->fileType;
+            statusp->Length = scp->length.LowPart;
+            statusp->Length_hi = scp->length.HighPart;
+        }
         statusp->InterfaceVersion = 0x1;
-        statusp->FileType = CM_SCACHETYPE_DIRECTORY;
         statusp->LinkCount = scp->linkCount;
-        statusp->Length = cm_fakeDirSize;
-        statusp->Length_hi = 0;
         statusp->DataVersion = (afs_uint32)(cm_data.fakeDirVersion & 0xFFFFFFFF);
         statusp->Author = 0x1;
         statusp->Owner = 0x0;
