@@ -439,7 +439,9 @@ extern "C" BOOL lana_IsLoopback(lana_number_t lana, BOOL reset)
     } astat;
     unsigned char kWLA_MAC[6] = { 0x02, 0x00, 0x4c, 0x4f, 0x4f, 0x50 };
     unsigned char kVista_WLA_MAC[6] = { 0x7F, 0x00, 0x00, 0x01, 0x4f, 0x50 };
+#ifdef USE_VMWARE
     unsigned char kVMWare_MAC[5] = { 0x00, 0x50, 0x56, 0xC0, 0x00 };
+#endif
     int status;
     HKEY hkConfig;
     LONG rv;
@@ -448,6 +450,7 @@ extern "C" BOOL lana_IsLoopback(lana_number_t lana, BOOL reset)
 
     rv = RegOpenKeyEx(HKEY_LOCAL_MACHINE,AFSREG_CLT_SVC_PARAM_SUBKEY,0,KEY_READ,&hkConfig);
     if (rv == ERROR_SUCCESS) {
+	dummyLen = sizeof(regLana);
         rv = RegQueryValueEx(hkConfig, szForceLanaLoopback, NULL, NULL, (LPBYTE) &regLana, &dummyLen);
         RegCloseKey(hkConfig);
 
@@ -491,8 +494,11 @@ extern "C" BOOL lana_IsLoopback(lana_number_t lana, BOOL reset)
         return FALSE;
     }
     return (memcmp(astat.status.adapter_address, kWLA_MAC, 6) == 0 ||
-	    memcmp(astat.status.adapter_address, kVista_WLA_MAC, 6) == 0 ||
-	    memcmp(astat.status.adapter_address, kVMWare_MAC, 5) == 0);
+	    memcmp(astat.status.adapter_address, kVista_WLA_MAC, 6) == 0 
+#ifdef USE_VMWARE
+             || memcmp(astat.status.adapter_address, kVMWare_MAC, 5) == 0
+#endif
+             );
 }
 
 // Get the netbios named used/to-be-used by the AFS SMB server.
@@ -566,8 +572,10 @@ extern "C" long lana_GetUncServerNameEx(char *buffer, lana_number_t * pLana, int
 	rv = RegQueryValueEx(hkConfig, szNetbiosNameValue, NULL, NULL, (LPBYTE) &regNbName, &dummyLen);
 	if(rv != ERROR_SUCCESS) 
 	    strcpy(regNbName, "AFS");
-	else 
-	    regNbName[15] = 0;
+	else {
+            /* Max Suffix Length is 6 */
+	    regNbName[6] = 0;
+        }
 
 	RegCloseKey(hkConfig);
     } else {
@@ -611,26 +619,30 @@ extern "C" long lana_GetUncServerNameEx(char *buffer, lana_number_t * pLana, int
     if(regNbName[0] &&
 	(regLana >=0 && lana_IsLoopback((lana_number_t) regLana,FALSE))) 	
     {
-        strncpy(nbName,regNbName,15);
-        nbName[16] = 0;
+        strncpy(nbName,regNbName,14);
+        nbName[14] = 0;
         strupr(nbName);
     } else {
-	char * dot;
-
 	if(flags & LANA_NETBIOS_NAME_SUFFIX) {
-	    strcpy(nbName,"-AFS");
+	    _snprintf(nbName, MAX_NB_NAME_LENGTH, "-%s", regNbName);
+            nbName[14] = 0;
 	} else {
+            char * dot;
+
 	    dummyLen = sizeof(hostname);
 	    // assume we are not a cluster.
 	    rv = GetComputerName(hostname, &dummyLen);
 	    if(!SUCCEEDED(rv)) { // should not happen, but...
 		return rv;
 	    }
-	    strncpy(nbName, hostname, 11);
-	    nbName[11] = 0;
+	    strncpy(nbName, hostname, MAX_NB_NAME_LENGTH);
+            nbName[MAX_NB_NAME_LENGTH-1] = 0;
+	    nbName[MAX_NB_NAME_LENGTH-strlen(regNbName)-2] = 0;
 	    if(dot = strchr(nbName,'.'))
 		*dot = 0;
-	    strcat(nbName,"-AFS");
+            strncat(nbName, "-", MAX_NB_NAME_LENGTH);
+	    strncat(nbName, regNbName, MAX_NB_NAME_LENGTH);
+            nbName[MAX_NB_NAME_LENGTH-1] = 0;
 	}
     }
 
