@@ -7,6 +7,9 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+#include <winsock2.h>
+#include <ws2tcpip.h>
+
 extern "C" {
 #include <afs/param.h>
 #include <afs/stds.h>
@@ -22,6 +25,7 @@ extern "C" {
 #define __CM_CONFIG_INTERFACES_ONLY__
 #include "../afsd/cm_config.h"
 
+#include "../afsd/cm_nls.h"
 #define __CM_IOCTL_INTERFACES_ONLY__
 #include "../afsd/cm_ioctl.h"
 
@@ -168,6 +172,7 @@ void Config_GetCellName (LPTSTR pszName)
 
 BOOL Config_ContactGateway (LPTSTR pszGateway, LPTSTR pszCell)
 {
+   // pszCell is MAX_PATH
    BOOL rc = FALSE;
 
    BYTE OutData[ PIOCTL_MAXSIZE ];
@@ -185,13 +190,14 @@ BOOL Config_ContactGateway (LPTSTR pszGateway, LPTSTR pszCell)
 
    ULONG status;
    if ((status = pioctl (0, VIOC_GET_WS_CELL, &IOInfo, 1)) == 0)
-      {
-      if (OutData[0])
-         {
-         lstrcpy (pszCell, (LPCTSTR)OutData);
-         rc = TRUE;
-         }
-      }
+   {
+       OutData[min(PIOCTL_MAXSIZE, MAX_PATH) - 1] = '\0';
+       if (OutData[0])
+       {
+           lstrcpy (pszCell, (LPCTSTR)OutData);
+           rc = TRUE;
+       }
+   }
 
    Config_SetGatewayName (szOldGateway);
 
@@ -780,11 +786,30 @@ BOOL Config_GetCacheInUse (ULONG *pckCacheInUse, ULONG *pStatus)
 void Config_GetCachePath (LPTSTR pszCachePath)
 {
     if (!Config_ReadGlobalString (TEXT("CachePath"), pszCachePath, MAX_PATH)) {
-        TCHAR szPath[MAX_PATH];
-        GetWindowsDirectory(szPath, sizeof(szPath));
-        szPath[2] = 0;	/* get drive letter only */
-        strcat(szPath, "\\AFSCache");
+        HKEY hk;
+        TCHAR szPath[ MAX_PATH ] = TEXT("");
 
+        if (RegOpenKeyEx (HKEY_LOCAL_MACHINE, TEXT("System\\CurrentControlSet\\Control\\Session Manager\\Environment"), 0, KEY_QUERY_VALUE, &hk) == ERROR_SUCCESS)
+        {
+            DWORD dwSize = sizeof(szPath);
+            DWORD dwType = 0; 
+
+            if (RegQueryValueEx (hk, TEXT("TEMP"), NULL, &dwType, (PBYTE)szPath, &dwSize) == ERROR_SUCCESS)
+            {
+                if ( dwType == REG_EXPAND_SZ ) {
+                    TCHAR szTemp[ MAX_PATH ];
+                    lstrcpy(szTemp, szPath);
+                    ExpandEnvironmentStrings(szTemp, szPath, MAX_PATH);
+                }
+            }
+            RegCloseKey (hk);
+            lstrcat(szPath, "\\AFSCache");
+        }
+
+        if ( !szPath[0] ) {
+            GetWindowsDirectory(szPath, sizeof(szPath));
+            lstrcat(szPath, "\\TEMP\\AFSCache");
+        }
         lstrcpy (pszCachePath, szPath);
     }
 }        
