@@ -27,8 +27,6 @@
      vgonel(struct vnode *vp, struct thread *td);
 #endif
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/FBSD/osi_vm.c,v 1.15.4.1 2008/08/26 14:01:33 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -201,7 +199,7 @@ osi_VM_StoreAllSegments(struct vcache *avc)
  * be some pages around when we return, newly created by concurrent activity.
  */
 void
-osi_VM_TryToSmush(struct vcache *avc, struct AFS_UCRED *acred, int sync)
+osi_VM_TryToSmush(struct vcache *avc, AFS_UCRED *acred, int sync)
 {
     struct vnode *vp;
     struct vm_object *obj;
@@ -250,7 +248,7 @@ osi_VM_TryToSmush(struct vcache *avc, struct AFS_UCRED *acred, int sync)
  * Locking:  No lock is held, not even the global lock.
  */
 void
-osi_VM_FlushPages(struct vcache *avc, struct AFS_UCRED *credp)
+osi_VM_FlushPages(struct vcache *avc, AFS_UCRED *credp)
 {
     struct vnode *vp;
     struct vm_object *obj;
@@ -272,7 +270,7 @@ osi_VM_FlushPages(struct vcache *avc, struct AFS_UCRED *credp)
  * it only works on Solaris.
  */
 void
-osi_VM_Truncate(struct vcache *avc, int alen, struct AFS_UCRED *acred)
+osi_VM_Truncate(struct vcache *avc, int alen, AFS_UCRED *acred)
 {
     vnode_pager_setsize(AFSTOV(avc), alen);
 }
