@@ -28,7 +28,7 @@ extern cred_t *crref(void);
 extern void crset(cred_t * cr);
 
 /* osi_nfssrv.c */
-extern int osi_linux_nfs_initreq(struct vrequest *av, struct AFS_UCRED *cr,
+extern int osi_linux_nfs_initreq(struct vrequest *av, AFS_UCRED *cr,
                                  int *code);
 extern void osi_linux_nfssrv_init(void);
 extern void osi_linux_nfssrv_shutdown(void);
@@ -38,6 +38,7 @@ extern afs_rwlock_t afs_xnfssrv;
 extern afs_rwlock_t afs_xosi;
 extern int osi_InitCacheInfo(char *aname);
 extern int osi_rdwr(struct osi_file *osifile, uio_t * uiop, int rw);
+extern struct file *afs_linux_raw_open(afs_dcache_id_t *ainode, ino_t *hint);
 
 /* osi_ioctl.c */
 extern void osi_ioctl_init(void);
@@ -70,13 +71,13 @@ extern void osi_sysctl_clean(void);
 
 /* osi_vm.c */
 extern int osi_VM_FlushVCache(struct vcache *avc, int *slept);
-extern void osi_VM_TryToSmush(struct vcache *avc, struct AFS_UCRED *acred,
+extern void osi_VM_TryToSmush(struct vcache *avc, AFS_UCRED *acred,
 			      int sync);
 extern void osi_VM_FSyncInval(struct vcache *avc);
 extern void osi_VM_StoreAllSegments(struct vcache *avc);
-extern void osi_VM_FlushPages(struct vcache *avc, struct AFS_UCRED *credp);
+extern void osi_VM_FlushPages(struct vcache *avc, AFS_UCRED *credp);
 extern void osi_VM_Truncate(struct vcache *avc, int alen,
-			    struct AFS_UCRED *acred);
+			    AFS_UCRED *acred);
 
 /* osi_vfsops.c */
 extern void vattr2inode(struct inode *ip, struct vattr *vp);
