@@ -1221,44 +1221,44 @@ struct usr_socket {
 ((sizeof (struct usr_dirent)+4 - (MAXNAMLEN+1)) + (((len)+1 + 3) &~ 3))
 
 struct vcache;
-#define AFS_UCRED usr_ucred
+#define AFS_UCRED struct usr_ucred
 #define AFS_FLOCK       flock
 
 
 struct usr_vnodeops {
-    int (*vn_open) (struct vcache **, afs_int32, struct AFS_UCRED *);
-    int (*vn_close) (struct vcache *, afs_int32, struct AFS_UCRED *);
+    int (*vn_open) (struct vcache **, afs_int32, AFS_UCRED *);
+    int (*vn_close) (struct vcache *, afs_int32, AFS_UCRED *);
     int (*vn_rdwr) (struct usr_vnode *avc, struct usr_uio *uio, 
 		    int rw, int io, struct usr_ucred *cred);
     int (*vn_ioctl) (void);
     int (*vn_select) (void);
-    int (*vn_getattr) (struct vcache *avc, struct vattr *, struct AFS_UCRED *);
-    int (*vn_setattr) (struct vcache *avc, struct vattr *, struct AFS_UCRED *);
-    int (*vn_access) (struct vcache *avc, afs_int32, struct AFS_UCRED *);
+    int (*vn_getattr) (struct vcache *avc, struct vattr *, AFS_UCRED *);
+    int (*vn_setattr) (struct vcache *avc, struct vattr *, AFS_UCRED *);
+    int (*vn_access) (struct vcache *avc, afs_int32, AFS_UCRED *);
     int (*vn_lookup) (struct vcache *adp, char *, struct vcache **, 
-		      struct AFS_UCRED *, int);
+		      AFS_UCRED *, int);
     int (*vn_create) (struct vcache *adp, char *, struct vattr *, 
-		      enum vcexcl, int, struct vcache **, struct AFS_UCRED *);
-    int (*vn_remove) (struct vcache *adp, char *, struct AFS_UCRED *);
+		      enum vcexcl, int, struct vcache **, AFS_UCRED *);
+    int (*vn_remove) (struct vcache *adp, char *, AFS_UCRED *);
     int (*vn_link) (struct vcache *avc, struct vcache *adp, char *, 
-		    struct AFS_UCRED *);
+		    AFS_UCRED *);
     int (*vn_rename) (struct vcache *aodp, char *, struct vcache *, char *,
-		      struct AFS_UCRED *);
+		      AFS_UCRED *);
     int (*vn_mkdir) (struct vcache *adp, char *, struct vattr *, 
-		     struct vcache **, struct AFS_UCRED *);
-    int (*vn_rmdir) (struct vcache *adp, char *, struct AFS_UCRED *);
-    int (*vn_readdir) (struct vcache *avc, struct uio *, struct AFS_UCRED *);
+		     struct vcache **, AFS_UCRED *);
+    int (*vn_rmdir) (struct vcache *adp, char *, AFS_UCRED *);
+    int (*vn_readdir) (struct vcache *avc, struct uio *, AFS_UCRED *);
     int (*vn_symlink) (struct vcache *adp, char *, struct vattr *, char *,
-		       struct AFS_UCRED *);
-    int (*vn_readlink) (struct vcache *avc, struct uio *, struct AFS_UCRED *);
-    int (*vn_fsync) (struct vcache *avc, struct AFS_UCRED *);
-    int (*vn_inactive) (struct vcache *avc, struct AFS_UCRED *acred);
+		       AFS_UCRED *);
+    int (*vn_readlink) (struct vcache *avc, struct uio *, AFS_UCRED *);
+    int (*vn_fsync) (struct vcache *avc, AFS_UCRED *);
+    int (*vn_inactive) (struct vcache *avc, AFS_UCRED *acred);
     int (*vn_bmap) (void);
     int (*vn_strategy) (void);
     int (*vn_bread) (void);
     int (*vn_brelse) (void);
     int (*vn_lockctl) (struct vcache *, struct AFS_FLOCK *, int,
-		       struct AFS_UCRED *);
+		       AFS_UCRED *);
     int (*vn_fid) (struct vcache *avc, struct fid **);
 };
 
@@ -1278,7 +1278,7 @@ extern struct usr_mount *getmp(unsigned long);
 typedef long usr_whymountroot_t;
 
 struct usr_vfsops {
-    int (*vfs_mount) (struct vfs *, char *, struct vfs *);
+    int (*vfs_mount) (struct vfs *, char *, void *);
     int (*vfs_unmount) (struct vfs *);
     int (*vfs_root) (struct vfs *, struct vnode **);
     int (*vfs_statfs) (struct vfs *, struct statfs *);
