@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/afs_call.c,v 1.86.4.25 2009/05/30 17:56:03 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -478,8 +476,30 @@ wait_for_cachedefs(void) {
 #endif
 }
 
+#ifdef AFS_DARWIN100_ENV
+#define AFSKPTR(X) k ## X
 int
-afs_syscall_call(long parm, long parm2, long parm3, long parm4, long parm5, long parm6)
+afs_syscall_call(long parm, long parm2, long parm3,
+		 long parm4, long parm5, long parm6)
+{
+    return afs_syscall64_call(CAST_USER_ADDR_T((parm)),
+			      CAST_USER_ADDR_T((parm2)),
+			      CAST_USER_ADDR_T((parm3)),
+			      CAST_USER_ADDR_T((parm4)),
+			      CAST_USER_ADDR_T((parm5)),
+			      CAST_USER_ADDR_T((parm6)));
+}
+#else
+#define AFSKPTR(X) ((caddr_t)X)
+#endif
+int
+#ifdef AFS_DARWIN100_ENV
+afs_syscall64_call(user_addr_t kparm, user_addr_t kparm2, user_addr_t kparm3,
+		 user_addr_t kparm4, user_addr_t kparm5, user_addr_t kparm6)
+#else
+afs_syscall_call(long parm, long parm2, long parm3,
+		 long parm4, long parm5, long parm6)
+#endif
 {
     afs_int32 code = 0;
 #if defined(AFS_SGI61_ENV) || defined(AFS_SUN57_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
@@ -487,6 +507,15 @@ afs_syscall_call(long parm, long parm2, long parm3, long parm4, long parm5, long
 #else /* AFS_SGI61_ENV */
     u_int bufferSize;
 #endif /* AFS_SGI61_ENV */
+#ifdef AFS_DARWIN100_ENV
+    /* AFSKPTR macro relies on this name format/mapping */
+    afs_uint32 parm = (afs_uint32)kparm;
+    afs_uint32 parm2 = (afs_uint32)kparm2;
+    afs_uint32 parm3 = (afs_uint32)kparm3;
+    afs_uint32 parm4 = (afs_uint32)kparm4;
+    afs_uint32 parm5 = (afs_uint32)kparm5;
+    afs_uint32 parm6 = (afs_uint32)kparm6;
+#endif
 
     AFS_STATCNT(afs_syscall_call);
     if (
@@ -685,14 +714,14 @@ afs_syscall_call(long parm, long parm2, long parm3, long parm4, long parm5, long
 
 	code = afs_InitDynroot();
 	if (!code) {
-	    AFS_COPYIN((char *)parm2, (char *)tcell->hosts, sizeof(tcell->hosts),
+	    AFS_COPYIN(AFSKPTR(parm2), (caddr_t)tcell->hosts, sizeof(tcell->hosts),
 		       code);
 	}
 	if (!code) {
 	    if (parm4 > sizeof(tcell->cellName))
 		code = EFAULT;
 	    else {
-		AFS_COPYIN((char *)parm3, tcell->cellName, parm4, code);
+	      AFS_COPYIN(AFSKPTR(parm3), (caddr_t)tcell->cellName, parm4, code);
 		if (!code)
 		    afs_NewCell(tcell->cellName, tcell->hosts, parm5, NULL, 0,
 				0, 0);
@@ -713,15 +742,15 @@ afs_syscall_call(long parm, long parm2, long parm3, long parm4, long parm5, long
 		afs_osi_Sleep(&afs_initState);
 #endif
 
-	    AFS_COPYIN((char *)parm2, (char *)tcell->hosts, sizeof(tcell->hosts),
+	    AFS_COPYIN(AFSKPTR(parm2), (caddr_t)tcell->hosts, sizeof(tcell->hosts),
 		       code);
 	}
 	if (!code) {
-	    AFS_COPYINSTR((char *)parm3, tbuffer1, AFS_SMALLOCSIZ,
+	    AFS_COPYINSTR(AFSKPTR(parm3), tbuffer1, AFS_SMALLOCSIZ,
 			  &bufferSize, code);
 	    if (!code) {
 		if (parm4 & 4) {
-		    AFS_COPYINSTR((char *)parm5, tbuffer, AFS_SMALLOCSIZ,
+		    AFS_COPYINSTR(AFSKPTR(parm5), tbuffer, AFS_SMALLOCSIZ,
 				  &bufferSize, code);
 		    if (!code) {
 			lcnamep = tbuffer;
@@ -748,11 +777,11 @@ afs_syscall_call(long parm, long parm2, long parm3, long parm4, long parm5, long
 
 	code = afs_InitDynroot();
 	if (!code) {
-	    AFS_COPYINSTR((char *)parm2, aliasName, AFS_SMALLOCSIZ, &bufferSize,
+	    AFS_COPYINSTR(AFSKPTR(parm2), aliasName, AFS_SMALLOCSIZ, &bufferSize,
 			  code);
 	}
 	if (!code)
-	    AFS_COPYINSTR((char *)parm3, cellName, AFS_SMALLOCSIZ,
+	    AFS_COPYINSTR(AFSKPTR(parm3), cellName, AFS_SMALLOCSIZ,
 			  &bufferSize, code);
 	if (!code)
 	    afs_NewCellAlias(aliasName, cellName);
@@ -767,7 +796,7 @@ afs_syscall_call(long parm, long parm2, long parm3, long parm4, long parm5, long
 
 	code = afs_InitDynroot();
 	if (!code) {
-	    AFS_COPYINSTR((char *)parm2, cell, AFS_SMALLOCSIZ, &bufferSize, code);
+	    AFS_COPYINSTR(AFSKPTR(parm2), cell, AFS_SMALLOCSIZ, &bufferSize, code);
 	}
 	if (!code)
 	    afs_SetPrimaryCell(cell);
@@ -778,7 +807,7 @@ afs_syscall_call(long parm, long parm2, long parm3, long parm4, long parm5, long
 	if (afs_CacheInit_Done)
 	    goto out;
 
-	AFS_COPYIN((char *)parm2, (caddr_t) & cparms, sizeof(cparms), code);
+	AFS_COPYIN(AFSKPTR(parm2), (caddr_t) & cparms, sizeof(cparms), code);
 	if (code) {
 #if defined(KERNEL_HAVE_UERROR)
 	    setuerror(code);
@@ -826,7 +855,7 @@ afs_syscall_call(long parm, long parm2, long parm3, long parm4, long parm5, long
 	    afs_osi_Sleep(&afs_initState);
 
 	if (parm2) {
-	    AFS_COPYINSTR((char *)parm2, afs_rootVolumeName,
+	    AFS_COPYINSTR(AFSKPTR(parm2), afs_rootVolumeName,
 			  sizeof(afs_rootVolumeName), &bufferSize, code);
 	    afs_rootVolumeName[sizeof(afs_rootVolumeName) - 1] = 0;
 	} else
@@ -837,7 +866,7 @@ afs_syscall_call(long parm, long parm2, long parm3, long parm4, long parm5, long
 	char *tbuffer = osi_AllocSmallSpace(AFS_SMALLOCSIZ);
 
 	code = 0;
-	AFS_COPYINSTR((char *)parm2, tbuffer, AFS_SMALLOCSIZ, &bufferSize,
+	AFS_COPYINSTR(AFSKPTR(parm2), tbuffer, AFS_SMALLOCSIZ, &bufferSize,
 		      code);
 	if (code) {
 	    osi_FreeSmallSpace(tbuffer);
@@ -847,7 +876,7 @@ afs_syscall_call(long parm, long parm2, long parm3, long parm4, long parm5, long
 	    tbuffer[AFS_SMALLOCSIZ - 1] = '\0';	/* null-terminate the name */
 	    /* We have the cache dir copied in.  Call the cache init routine */
 #ifdef AFS_DARWIN80_ENV
-    get_vfs_context();
+	    get_vfs_context();
 #endif
 	    if (parm == AFSOP_CACHEBASEDIR) {
 		strncpy(afs_cachebasedir, tbuffer, 1024);
@@ -952,39 +981,43 @@ afs_syscall_call(long parm, long parm2, long parm3, long parm4, long parm5, long
 	    count = AFS_MAX_INTERFACE_ADDR;
 	}
 
-	AFS_COPYIN((char *)parm3, (char *)buffer, count * sizeof(afs_int32),
+	AFS_COPYIN(AFSKPTR(parm3), (caddr_t)buffer, count * sizeof(afs_int32),
 		   code);
-	if (parm4)
-	    AFS_COPYIN((char *)parm4, (char *)maskbuffer,
+	if (parm4 && !code)
+	    AFS_COPYIN(AFSKPTR(parm4), (caddr_t)maskbuffer,
 		       count * sizeof(afs_int32), code);
-	if (parm5)
-	    AFS_COPYIN((char *)parm5, (char *)mtubuffer,
+	if (parm5 && !code)
+	    AFS_COPYIN(AFSKPTR(parm5), (caddr_t)mtubuffer,
 		       count * sizeof(afs_int32), code);
 
-	afs_cb_interface.numberOfInterfaces = count;
-	for (i = 0; i < count; i++) {
-	    afs_cb_interface.addr_in[i] = buffer[i];
+	if (!code) {
+	    afs_cb_interface.numberOfInterfaces = count;
+	    for (i = 0; i < count; i++) {
+		afs_cb_interface.addr_in[i] = buffer[i];
 #ifdef AFS_USERSPACE_IP_ADDR
-	    /* AFS_USERSPACE_IP_ADDR means we have no way of finding the
-	     * machines IP addresses when in the kernel (the in_ifaddr
-	     * struct is not available), so we pass the info in at
-	     * startup. We also pass in the subnetmask and mtu size. The
-	     * subnetmask is used when setting the rank:
-	     * afsi_SetServerIPRank(); and the mtu size is used when
-	     * finding the best mtu size. rxi_FindIfnet() is replaced
-	     * with rxi_Findcbi().
-	     */
-	    afs_cb_interface.subnetmask[i] =
-		(parm4 ? maskbuffer[i] : 0xffffffff);
-	    afs_cb_interface.mtu[i] = (parm5 ? mtubuffer[i] : htonl(1500));
+		/* AFS_USERSPACE_IP_ADDR means we have no way of finding the
+		 * machines IP addresses when in the kernel (the in_ifaddr
+		 * struct is not available), so we pass the info in at
+		 * startup. We also pass in the subnetmask and mtu size. The
+		 * subnetmask is used when setting the rank:
+		 * afsi_SetServerIPRank(); and the mtu size is used when
+		 * finding the best mtu size. rxi_FindIfnet() is replaced
+		 * with rxi_Findcbi().
+		 */
+		afs_cb_interface.subnetmask[i] =
+		    (parm4 ? maskbuffer[i] : 0xffffffff);
+		afs_cb_interface.mtu[i] = (parm5 ? mtubuffer[i] : htonl(1500));
 #endif
-	}
-	rxi_setaddr(buffer[0]);
-	if (!refresh) {
-	    if (rxbind)
-		rx_bindhost = buffer[0];
-	    else
-		rx_bindhost = htonl(INADDR_ANY);
+	    }
+	    rxi_setaddr(buffer[0]);
+	    if (!refresh) {
+		if (rxbind)
+		    rx_bindhost = buffer[0];
+		else
+		    rx_bindhost = htonl(INADDR_ANY);
+	    }
+	} else {
+	    refresh = 0;
 	}
 
 	afs_osi_Free(buffer, sizeof(afs_int32) * AFS_MAX_INTERFACE_ADDR);
@@ -1060,8 +1093,8 @@ afs_syscall_call(long parm, long parm2, long parm3, long parm4, long parm5, long
 #endif /* else AFS_USERSPACE_IP_ADDR */
 #endif /* !AFS_SUN5_ENV */
 	if (!code)
-	    AFS_COPYOUT((caddr_t) & mtu, (caddr_t) parm3, sizeof(afs_int32),
-			code);
+	    AFS_COPYOUT((caddr_t) & mtu, AFSKPTR(parm3),
+			sizeof(afs_int32), code);
 #ifdef AFS_AIX32_ENV
 /* this is disabled for now because I can't figure out how to get access
  * to these kernel variables.  It's only for supporting user-mode rx
@@ -1098,8 +1131,8 @@ afs_syscall_call(long parm, long parm2, long parm3, long parm4, long parm5, long
 #endif /* else AFS_USERSPACE_IP_ADDR */
 #endif /* !AFS_SUN5_ENV */
 	if (!code)
-	    AFS_COPYOUT((caddr_t) & mask, (caddr_t) parm3, sizeof(afs_int32),
-			code);
+	    AFS_COPYOUT((caddr_t) & mask, AFSKPTR(parm3),
+			sizeof(afs_int32), code);
     }
 #ifdef AFS_AFSDB_ENV
     else if (parm == AFSOP_AFSDB_HANDLER) {
@@ -1112,8 +1145,8 @@ afs_syscall_call(long parm, long parm2, long parm3, long parm4, long parm5, long
 #ifndef UKERNEL
 	afs_osi_MaskUserLoop();
 #endif
-	AFS_COPYIN((afs_int32 *) parm2, cellname, cellLen, code);
-	AFS_COPYIN((afs_int32 *) parm3, kmsg, kmsgLen, code);
+	AFS_COPYIN(AFSKPTR(parm2), cellname, cellLen, code);
+	AFS_COPYIN(AFSKPTR(parm3), kmsg, kmsgLen, code);
 	if (!code) {
 	    code = afs_AFSDBHandler(cellname, cellLen, kmsg);
 	    if (*cellname == 1)
@@ -1124,7 +1157,7 @@ afs_syscall_call(long parm, long parm2, long parm3, long parm4, long parm5, long
 	    }
 	}
 	if (!code)
-	    AFS_COPYOUT(cellname, (char *)parm2, cellLen, code);
+	    AFS_COPYOUT(cellname, AFSKPTR(parm2), cellLen, code);
 	afs_osi_Free(kmsg, kmsgLen);
 	afs_osi_Free(cellname, cellLen);
     }
@@ -1140,9 +1173,10 @@ afs_syscall_call(long parm, long parm2, long parm3, long parm4, long parm5, long
 	rx_extraPackets = parm2;
 	afscall_set_rxpck_received = 1;
     } else if (parm == AFSOP_SET_RXMAXMTU) {
-    rx_MyMaxSendSize = rx_maxReceiveSizeUser = rx_maxReceiveSize = parm2;
-    } else
+	rx_MyMaxSendSize = rx_maxReceiveSizeUser = rx_maxReceiveSize = parm2;
+    } else {
 	code = EINVAL;
+    }
 
   out:
     AFS_GUNLOCK();
