@@ -13,8 +13,6 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/afs_cell.c,v 1.34.4.10 2008/11/29 18:20:24 shadow Exp $");
 
 #include "afs/stds.h"
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
@@ -61,6 +59,7 @@ afs_StopAFSDB(void)
     } else {
 	afsdb_handler_shutdown = 1;
 	afs_termState = AFSOP_STOP_RXEVENT;
+	afs_osi_Wakeup(&afs_termState);
     }
 }
 
@@ -215,14 +214,8 @@ afs_LookupAFSDB(char *acellName)
  */
 
 struct cell_name *afs_cellname_head;	/* Export for kdump */
-#if defined(LINUX_USE_FH)
-struct fid afs_cellname_fh;
-int afs_cellname_fh_type;
-static int afs_cellname_fh_set;
-#else
-static ino_t afs_cellname_inode;
+static afs_dcache_id_t afs_cellname_inode;
 static int afs_cellname_inode_set;
-#endif
 static int afs_cellname_dirty;
 static afs_int32 afs_cellnum_next;
 
@@ -307,11 +300,7 @@ afs_cellname_ref(struct cell_name *cn)
  * \return 0 for success. < 0 for error.
  */
 int
-#if defined(LINUX_USE_FH)
-afs_cellname_init(struct fid *fh, int fh_type, int lookupcode)
-#else
-afs_cellname_init(ino_t inode, int lookupcode)
-#endif
+afs_cellname_init(afs_dcache_id_t *inode, int lookupcode)
 {
     struct osi_file *tfile;
     int cc, off = 0;
@@ -330,24 +319,14 @@ afs_cellname_init(ino_t inode, int lookupcode)
 	return lookupcode;
     }
 
-#if defined(LINUX_USE_FH)
-    tfile = osi_UFSOpen_fh(fh, fh_type);
-#else
     tfile = osi_UFSOpen(inode);
-#endif
     if (!tfile) {
 	ReleaseWriteLock(&afs_xcell);
 	return EIO;
     }
 
-#if defined(LINUX_USE_FH)
-    memcpy(&afs_cellname_fh, fh, sizeof(struct fid));
-    afs_cellname_fh_type = fh_type;
-    afs_cellname_fh_set = 1;
-#else
-    afs_cellname_inode = inode;
+    afs_copy_inode(&afs_cellname_inode, inode);
     afs_cellname_inode_set = 1;
-#endif
 
     while (1) {
 	afs_int32 cellnum, clen, magic;
@@ -408,11 +387,7 @@ afs_cellname_write(void)
     struct cell_name *cn;
     int off;
 
-#if defined(LINUX_USE_FH)
-    if (!afs_cellname_dirty || !afs_cellname_fh_set)
-#else
     if (!afs_cellname_dirty || !afs_cellname_inode_set)
-#endif
 	return 0;
     if (afs_initState != 300)
 	return 0;
@@ -420,11 +395,7 @@ afs_cellname_write(void)
     ObtainWriteLock(&afs_xcell, 693);
     afs_cellname_dirty = 0;
     off = 0;
-#if defined(LINUX_USE_FH)
-    tfile = osi_UFSOpen_fh(&afs_cellname_fh, afs_cellname_fh_type);
-#else
-    tfile = osi_UFSOpen(afs_cellname_inode);
-#endif
+    tfile = osi_UFSOpen(&afs_cellname_inode);
     if (!tfile) {
 	ReleaseWriteLock(&afs_xcell);
 	return EIO;
@@ -952,7 +923,7 @@ afs_NewCell(char *acellName, afs_int32 * acellHosts, int aflags,
 	tc->fsport = AFS_FSPORT;
 	tc->vlport = AFS_VLPORT;
 	AFS_MD5_String(tc->cellHandle, tc->cellName, strlen(tc->cellName));
-	RWLOCK_INIT(&tc->lock, "cell lock");
+	AFS_RWLOCK_INIT(&tc->lock, "cell lock");
 	newc = 1;
 	aflags |= CNoSUID;
     }
@@ -1068,10 +1039,10 @@ afs_NewCell(char *acellName, afs_int32 * acellHosts, int aflags,
 void
 afs_CellInit(void)
 {
-    RWLOCK_INIT(&afs_xcell, "afs_xcell");
+    AFS_RWLOCK_INIT(&afs_xcell, "afs_xcell");
 #ifdef AFS_AFSDB_ENV
-    RWLOCK_INIT(&afsdb_client_lock, "afsdb_client_lock");
-    RWLOCK_INIT(&afsdb_req_lock, "afsdb_req_lock");
+    AFS_RWLOCK_INIT(&afsdb_client_lock, "afsdb_client_lock");
+    AFS_RWLOCK_INIT(&afsdb_req_lock, "afsdb_req_lock");
 #endif
     QInit(&CellLRU);
 
@@ -1088,7 +1059,7 @@ shutdown_cell(void)
     struct afs_q *cq, *tq;
     struct cell *tc;
 
-    RWLOCK_INIT(&afs_xcell, "afs_xcell");
+    AFS_RWLOCK_INIT(&afs_xcell, "afs_xcell");
 
     for (cq = CellLRU.next; cq != &CellLRU; cq = tq) {
 	tc = QTOC(cq);
