@@ -246,7 +246,7 @@ acl2_to_afs_call(int which, caddr_t * args, fhandle_t ** fhpp)
 int
 afs_nfs2_dispatcher(int type, afs_int32 which, char *argp,
 		    struct exportinfo **expp, struct svc_req *rp,
-		    struct AFS_UCRED *crp)
+		    AFS_UCRED *crp)
 {
     afs_int32 call = 0;
     afs_int32 code = 0;
@@ -376,8 +376,8 @@ void
 afs_nfs2_getattr(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call = afs_nfs2_dispatcher(0, RFS_GETATTR, (char *)args, &exp, rp, crp);
     if (call > 1)
 	afs_nfs2_noaccess((struct afs_nfs2_resp *)xp);
@@ -391,8 +391,8 @@ void
 afs_nfs2_setattr(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call = afs_nfs2_dispatcher(0, RFS_SETATTR, (char *)args, &exp, rp, crp);
     if (call > 1)
 	afs_nfs2_noaccess((struct afs_nfs2_resp *)xp);
@@ -406,8 +406,8 @@ void
 afs_nfs2_lookup(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call = afs_nfs2_dispatcher(0, RFS_LOOKUP, (char *)args, &exp, rp, crp);
     if (call > 1)
 	afs_nfs2_noaccess((struct afs_nfs2_resp *)xp);
@@ -424,8 +424,8 @@ void
 afs_nfs2_readlink(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call = afs_nfs2_dispatcher(0, RFS_READLINK, (char *)args, &exp, rp, crp);
     if (call > 1)
 	afs_nfs2_noaccess((struct afs_nfs2_resp *)xp);
@@ -439,8 +439,8 @@ void
 afs_nfs2_read(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call = afs_nfs2_dispatcher(0, RFS_READ, (char *)args, &exp, rp, crp);
     if (call > 1)
 	afs_nfs2_noaccess((struct afs_nfs2_resp *)xp);
@@ -454,8 +454,8 @@ void
 afs_nfs2_write(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call = afs_nfs2_dispatcher(0, RFS_WRITE, (char *)args, &exp, rp, crp);
     if (call > 1)
 	afs_nfs2_noaccess((struct afs_nfs2_resp *)xp);
@@ -469,8 +469,8 @@ void
 afs_nfs2_create(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call = afs_nfs2_dispatcher(0, RFS_CREATE, (char *)args, &exp, rp, crp);
     if (call > 1)
 	afs_nfs2_noaccess((struct afs_nfs2_resp *)xp);
@@ -487,8 +487,8 @@ void
 afs_nfs2_remove(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call = afs_nfs2_dispatcher(0, RFS_REMOVE, (char *)args, &exp, rp, crp);
     if (call > 1)
 	afs_nfs2_noaccess((struct afs_nfs2_resp *)xp);
@@ -502,8 +502,8 @@ void
 afs_nfs2_rename(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call = afs_nfs2_dispatcher(0, RFS_RENAME, (char *)args, &exp, rp, crp);
     if (call > 1)
 	afs_nfs2_noaccess((struct afs_nfs2_resp *)xp);
@@ -517,8 +517,8 @@ void
 afs_nfs2_link(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call = afs_nfs2_dispatcher(0, RFS_LINK, (char *)args, &exp, rp, crp);
     if (call > 1)
 	afs_nfs2_noaccess((struct afs_nfs2_resp *)xp);
@@ -532,8 +532,8 @@ void
 afs_nfs2_symlink(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call = afs_nfs2_dispatcher(0, RFS_SYMLINK, (char *)args, &exp, rp, crp);
     if (call > 1)
 	afs_nfs2_noaccess((struct afs_nfs2_resp *)xp);
@@ -547,8 +547,8 @@ void
 afs_nfs2_mkdir(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call = afs_nfs2_dispatcher(0, RFS_MKDIR, (char *)args, &exp, rp, crp);
     if (call > 1)
 	afs_nfs2_noaccess((struct afs_nfs2_resp *)xp);
@@ -565,8 +565,8 @@ void
 afs_nfs2_rmdir(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call = afs_nfs2_dispatcher(0, RFS_RMDIR, (char *)args, &exp, rp, crp);
     if (call > 1)
 	afs_nfs2_noaccess((struct afs_nfs2_resp *)xp);
@@ -580,8 +580,8 @@ void
 afs_nfs2_readdir(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call = afs_nfs2_dispatcher(0, RFS_READDIR, (char *)args, &exp, rp, crp);
     if (call > 1)
 	afs_nfs2_noaccess((struct afs_nfs2_resp *)xp);
@@ -595,8 +595,8 @@ void
 afs_nfs2_statfs(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call = afs_nfs2_dispatcher(0, RFS_STATFS, (char *)args, &exp, rp, crp);
     if (call > 1)
 	afs_nfs2_noaccess((struct afs_nfs2_resp *)xp);
@@ -631,8 +631,8 @@ void
 afs_acl2_getacl(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs2_dispatcher(1, ACLPROC2_GETACL, (char *)args, &exp, rp, crp);
     if (call > 1)
@@ -648,8 +648,8 @@ void
 afs_acl2_setacl(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs2_dispatcher(1, ACLPROC2_SETACL, (char *)args, &exp, rp, crp);
     if (call > 1)
@@ -665,8 +665,8 @@ void
 afs_acl2_getattr(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs2_dispatcher(1, ACLPROC2_GETATTR, (char *)args, &exp, rp, crp);
     if (call > 1)
@@ -682,8 +682,8 @@ void
 afs_acl2_access(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs2_dispatcher(1, ACLPROC2_ACCESS, (char *)args, &exp, rp, crp);
     if (call > 1)
@@ -700,8 +700,8 @@ void
 afs_acl2_getxattrdir(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs2_dispatcher(1, ACLPROC2_GETXATTRDIR, (char *)args, &exp, rp, crp);
     if (call > 1)
@@ -1025,7 +1025,7 @@ acl3_to_afs_call(int which, caddr_t * args, nfs_fh3 ** fhpp)
 int
 afs_nfs3_dispatcher(int type, afs_int32 which, char *argp,
 		    struct exportinfo **expp, struct svc_req *rp,
-		    struct AFS_UCRED *crp)
+		    AFS_UCRED *crp)
 {
     afs_int32 call = 0;
     afs_int32 code = 0;
@@ -1138,8 +1138,8 @@ afs_nfs3_getattr(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
     afs_nfs3_resp dummy;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs3_dispatcher(0, NFSPROC3_GETATTR, (char *)args, &exp, rp, crp);
     if (call > 1)
@@ -1156,8 +1156,8 @@ afs_nfs3_setattr(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
     afs_nfs3_resp dummy;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs3_dispatcher(0, NFSPROC3_SETATTR, (char *)args, &exp, rp, crp);
     if (call > 1)
@@ -1174,8 +1174,8 @@ afs_nfs3_lookup(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
     afs_nfs3_resp dummy;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs3_dispatcher(0, NFSPROC3_LOOKUP, (char *)args, &exp, rp, crp);
     if (call > 1)
@@ -1197,8 +1197,8 @@ afs_nfs3_access(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
     afs_nfs3_resp dummy;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs3_dispatcher(0, NFSPROC3_ACCESS, (char *)args, &exp, rp, crp);
     if (call > 1)
@@ -1215,8 +1215,8 @@ afs_nfs3_readlink(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
     afs_nfs3_resp dummy;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs3_dispatcher(0, NFSPROC3_READLINK, (char *)args, &exp, rp,
 			    crp);
@@ -1234,8 +1234,8 @@ afs_nfs3_read(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
     afs_nfs3_resp dummy;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call = afs_nfs3_dispatcher(0, NFSPROC3_READ, (char *)args, &exp, rp, crp);
     if (call > 1)
 	afs_nfs3_noaccess((struct afs_nfs3_resp *)xp);
@@ -1251,8 +1251,8 @@ afs_nfs3_write(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
     afs_nfs3_resp dummy;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs3_dispatcher(0, NFSPROC3_WRITE, (char *)args, &exp, rp, crp);
     if (call > 1)
@@ -1269,8 +1269,8 @@ afs_nfs3_create(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
     afs_nfs3_resp dummy;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs3_dispatcher(0, NFSPROC3_CREATE, (char *)args, &exp, rp, crp);
     if (call > 1)
@@ -1292,8 +1292,8 @@ afs_nfs3_mkdir(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
     afs_nfs3_resp dummy;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs3_dispatcher(0, NFSPROC3_MKDIR, (char *)args, &exp, rp, crp);
     if (call > 1)
@@ -1315,8 +1315,8 @@ afs_nfs3_symlink(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
     afs_nfs3_resp dummy;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs3_dispatcher(0, NFSPROC3_SYMLINK, (char *)args, &exp, rp, crp);
     if (call > 1)
@@ -1338,8 +1338,8 @@ afs_nfs3_mknod(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
     afs_nfs3_resp dummy;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs3_dispatcher(0, NFSPROC3_MKNOD, (char *)args, &exp, rp, crp);
     if (call > 1)
@@ -1361,8 +1361,8 @@ afs_nfs3_remove(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
     afs_nfs3_resp dummy;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs3_dispatcher(0, NFSPROC3_REMOVE, (char *)args, &exp, rp, crp);
     if (call > 1)
@@ -1379,8 +1379,8 @@ afs_nfs3_rmdir(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
     afs_nfs3_resp dummy;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs3_dispatcher(0, NFSPROC3_RMDIR, (char *)args, &exp, rp, crp);
     if (call > 1)
@@ -1397,8 +1397,8 @@ afs_nfs3_rename(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
     afs_nfs3_resp dummy;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs3_dispatcher(0, NFSPROC3_RENAME, (char *)args, &exp, rp, crp);
     if (call > 1)
@@ -1415,8 +1415,8 @@ afs_nfs3_link(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
     afs_nfs3_resp dummy;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call = afs_nfs3_dispatcher(0, NFSPROC3_LINK, (char *)args, &exp, rp, crp);
     if (call > 1)
 	afs_nfs3_noaccess((struct afs_nfs3_resp *)xp);
@@ -1432,8 +1432,8 @@ afs_nfs3_readdir(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
     afs_nfs3_resp dummy;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs3_dispatcher(0, NFSPROC3_READDIR, (char *)args, &exp, rp, crp);
     if (call > 1)
@@ -1450,8 +1450,8 @@ afs_nfs3_readdirplus(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
     afs_nfs3_resp dummy;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs3_dispatcher(0, NFSPROC3_READDIRPLUS, (char *)args, &exp, rp,
 			    crp);
@@ -1471,8 +1471,8 @@ afs_nfs3_fsstat(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
     afs_nfs3_resp dummy;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs3_dispatcher(0, NFSPROC3_FSSTAT, (char *)args, &exp, rp, crp);
     if (call > 1)
@@ -1489,8 +1489,8 @@ afs_nfs3_fsinfo(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
     afs_nfs3_resp dummy;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs3_dispatcher(0, NFSPROC3_FSINFO, (char *)args, &exp, rp, crp);
     if (call > 1)
@@ -1507,8 +1507,8 @@ afs_nfs3_pathconf(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
     afs_nfs3_resp dummy;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs3_dispatcher(0, NFSPROC3_PATHCONF, (char *)args, &exp, rp,
 			    crp);
@@ -1526,8 +1526,8 @@ afs_nfs3_commit(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
     afs_nfs3_resp dummy;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs3_dispatcher(0, NFSPROC3_COMMIT, (char *)args, &exp, rp, crp);
     if (call > 1)
@@ -1568,8 +1568,8 @@ void
 afs_acl3_getacl(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs3_dispatcher(1, ACLPROC3_GETACL, (char *)args, &exp, rp, crp);
     if (call > 1)
@@ -1585,8 +1585,8 @@ void
 afs_acl3_setacl(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs3_dispatcher(1, ACLPROC3_SETACL, (char *)args, &exp, rp, crp);
     if (call > 1)
@@ -1603,8 +1603,8 @@ void
 afs_acl3_getxattrdir(char *args, char *xp, char *exp, char *rp, char *crp)
 {
     u_int call;
-    struct AFS_UCRED *svcred = curthread->t_cred;
-    curthread->t_cred = (struct AFS_UCRED *)crp;
+    AFS_UCRED *svcred = curthread->t_cred;
+    curthread->t_cred = (AFS_UCRED *)crp;
     call =
 	afs_nfs3_dispatcher(1, ACLPROC3_GETXATTRDIR, (char *)args, &exp, rp, crp);
     if (call > 1)
