@@ -146,7 +146,7 @@ static int afs_pag_sleepcnt = 0;
 static int afs_pag_timewarn = 0;
 
 static int
-afs_pag_sleep(struct AFS_UCRED **acred)
+afs_pag_sleep(AFS_UCRED **acred)
 {
     int rv = 0;
 
@@ -167,7 +167,7 @@ afs_pag_sleep(struct AFS_UCRED **acred)
 }
 
 static int
-afs_pag_wait(struct AFS_UCRED **acred)
+afs_pag_wait(AFS_UCRED **acred)
 {
     if (afs_pag_sleep(acred)) {
 	if (!afs_pag_sleepcnt) {
@@ -190,7 +190,7 @@ afs_pag_wait(struct AFS_UCRED **acred)
 
 int
 #if	defined(AFS_SUN5_ENV)
-afs_setpag(struct AFS_UCRED **credpp)
+afs_setpag(AFS_UCRED **credpp)
 #elif  defined(AFS_OSF_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
 afs_setpag(struct proc *p, void *args, int *retval)
 #else
@@ -199,11 +199,11 @@ afs_setpag(void)
 {
 
 #if     defined(AFS_SUN5_ENV)
-    struct AFS_UCRED **acred = *credpp;
+    AFS_UCRED **acred = *credpp;
 #elif  defined(AFS_OBSD_ENV)
-    struct AFS_UCRED **acred = &p->p_ucred;
+    AFS_UCRED **acred = &p->p_ucred;
 #else
-    struct AFS_UCRED **acred = NULL;
+    AFS_UCRED **acred = NULL;
 #endif
 
     int code = 0;
@@ -248,19 +248,19 @@ afs_setpag(void)
     }
 #elif	defined(AFS_LINUX20_ENV)
     {
-	struct AFS_UCRED *credp = crref();
+	AFS_UCRED *credp = crref();
 	code = AddPag(genpag(), &credp);
 	crfree(credp);
     }
 #elif defined(AFS_DARWIN80_ENV)
     {
-	struct AFS_UCRED *credp = kauth_cred_proc_ref(p);
+	AFS_UCRED *credp = kauth_cred_proc_ref(p);
 	code = AddPag(p, genpag(), &credp);
 	crfree(credp);
     }
 #elif defined(AFS_DARWIN_ENV)
     {
-	struct AFS_UCRED *credp = crdup(p->p_cred->pc_ucred);
+	AFS_UCRED *credp = crdup(p->p_cred->pc_ucred);
 	code = AddPag(p, genpag(), &credp);
 	crfree(credp);
     }
@@ -292,7 +292,7 @@ afs_setpag(void)
  */
 int
 #if	defined(AFS_SUN5_ENV)
-afs_setpag_val(struct AFS_UCRED **credpp, int pagval)
+afs_setpag_val(AFS_UCRED **credpp, int pagval)
 #elif  defined(AFS_OSF_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
 afs_setpag_val(struct proc *p, void *args, int *retval, int pagval)
 #else
@@ -301,11 +301,11 @@ afs_setpag_val(int pagval)
 {
 
 #if     defined(AFS_SUN5_ENV)
-    struct AFS_UCRED **acred = *credp;
+    AFS_UCRED **acred = *credp;
 #elif  defined(AFS_OBSD_ENV)
-    struct AFS_UCRED **acred = &p->p_ucred;
+    AFS_UCRED **acred = &p->p_ucred;
 #else
-    struct AFS_UCRED **acred = NULL;
+    AFS_UCRED **acred = NULL;
 #endif
 
     int code = 0;
@@ -349,7 +349,7 @@ afs_setpag_val(int pagval)
     }
 #elif	defined(AFS_LINUX20_ENV)
     {
-	struct AFS_UCRED *credp = crref();
+	AFS_UCRED *credp = crref();
 	code = AddPag(pagval, &credp);
 	crfree(credp);
     }
@@ -379,7 +379,7 @@ int
 afs_getpag_val(void)
 {
     int pagvalue;
-    struct AFS_UCRED *credp = u.u_cred;
+    AFS_UCRED *credp = u.u_cred;
     gid_t gidset0, gidset1;
 #ifdef AFS_SUN510_ENV
     const gid_t *gids;
@@ -401,10 +401,10 @@ afs_getpag_val(void)
 /* Note - needs to be available on AIX, others can be static - rework this */
 #if defined(AFS_OSF_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
 int
-AddPag(struct proc *p, afs_int32 aval, struct AFS_UCRED **credpp)
+AddPag(struct proc *p, afs_int32 aval, AFS_UCRED **credpp)
 #else
 int
-AddPag(afs_int32 aval, struct AFS_UCRED **credpp)
+AddPag(afs_int32 aval, AFS_UCRED **credpp)
 #endif
 {
     afs_int32 code;
@@ -426,24 +426,17 @@ AddPag(afs_int32 aval, struct AFS_UCRED **credpp)
 
 
 int
-afs_InitReq(register struct vrequest *av, struct AFS_UCRED *acred)
+afs_InitReq(register struct vrequest *av, AFS_UCRED *acred)
 {
 #if defined(AFS_LINUX26_ENV) && !defined(AFS_NONFSTRANS)
     int code;
 #endif
-    int i = 0;
 
     AFS_STATCNT(afs_InitReq);
     memset(av, 0, sizeof(*av));
     if (afs_shuttingdown)
 	return EIO;
 
-    av->idleError = 0;
-    av->tokenError = 0;
-    while (i < MAXHOSTS) {
-      av->skipserver[i] = 0;
-      i++;
-    }
 #ifdef AFS_LINUX26_ENV
 #if !defined(AFS_NONFSTRANS)
     if (osi_linux_nfs_initreq(av, acred, &code))
@@ -469,7 +462,6 @@ afs_InitReq(register struct vrequest *av, struct AFS_UCRED *acred)
 	av->uid = acred->cr_ruid;	/* default when no pag is set */
 #endif
     }
-    av->initd = 0;
     return 0;
 }
 
@@ -545,7 +537,7 @@ afs_get_groups_from_pag(afs_uint32 pag, gid_t * g0p, gid_t * g1p)
 
 
 afs_int32
-PagInCred(struct AFS_UCRED *cred)
+PagInCred(AFS_UCRED *cred)
 {
     afs_int32 pag;
 #if !defined(AFS_LINUX26_ONEGROUP_ENV)
