@@ -40,8 +40,6 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/afs_vcache.c,v 1.114.2.30 2009/03/25 19:34:48 shadow Exp $");
 
 #include "afs/sysincludes.h"	/*Standard vendor system headers */
 #include "afsincludes.h"	/*AFS-based standard headers */
@@ -87,8 +85,10 @@ extern int afsd_dynamic_vcaches;
 
 /* Disk backed vcache definitions 
  * Both protected by xvcache */
+#ifdef AFS_DISCON_ENV
 static int afs_nextVcacheSlot = 0;
 static struct afs_slotlist *afs_freeSlotList = NULL;
+#endif
 
 /* Forward declarations */
 static afs_int32 afs_QueueVCB(struct vcache *avc);
@@ -294,7 +294,7 @@ afs_FlushVCache(struct vcache *avc, int *slept)
  * \param acred
  */
 void
-afs_InactiveVCache(struct vcache *avc, struct AFS_UCRED *acred)
+afs_InactiveVCache(struct vcache *avc, AFS_UCRED *acred)
 {
     AFS_STATCNT(afs_inactive);
     if (avc->f.states & CDirty) {
@@ -630,7 +630,7 @@ int
 afs_ShakeLooseVCaches(afs_int32 anumber)
 {
 #if defined(AFS_OSF_ENV) || defined(AFS_LINUX22_ENV)
-    afs_int32 i, j;
+    afs_int32 i;
     struct vcache *tvc;
     struct afs_q *tq, *uq;
     int code, fv_slept;
@@ -649,8 +649,6 @@ afs_ShakeLooseVCaches(afs_int32 anumber)
 #endif
 	afs_vcount >= afs_maxvcount
 	) {
-	int i;
-
 	i = 0;
 	for (tq = VLRU.prev; tq != &VLRU && anumber > 0; tq = uq) {
 	    tvc = QTOV(tq);
@@ -784,7 +782,7 @@ afs_AllocVCache(void)
     /* track the peak */
     if (afsd_dynamic_vcaches && afs_maxvcount < afs_vcount) {
 	afs_maxvcount = afs_vcount;
-	printf("peak vnodes: %d\n", afs_maxvcount);
+	/*printf("peak vnodes: %d\n", afs_maxvcount);*/
     }
 #endif
     afs_stats_cmperf.vcacheXAllocs++;	/* count in case we have a leak */
@@ -858,8 +856,10 @@ afs_NewVCache(struct VenusFid *afid, struct server *serverp)
 #ifdef	AFS_AIX_ENV
     struct gnode *gnodepnt;
 #endif
+#if !defined(AFS_OSF_ENV) && !defined(AFS_LINUX22_ENV)
     struct afs_q *tq, *uq;
     int code, fv_slept;
+#endif
 
     AFS_STATCNT(afs_NewVCache);
 
@@ -1000,9 +1000,9 @@ afs_NewVCache(struct VenusFid *afid, struct server *serverp)
     memset(&(tvc->f), 0, sizeof(struct fvcache));
 #endif
 
-    RWLOCK_INIT(&tvc->lock, "vcache lock");
+    AFS_RWLOCK_INIT(&tvc->lock, "vcache lock");
 #if	defined(AFS_SUN5_ENV)
-    RWLOCK_INIT(&tvc->vlock, "vcache vlock");
+    AFS_RWLOCK_INIT(&tvc->vlock, "vcache vlock");
 #endif /* defined(AFS_SUN5_ENV) */
 
     tvc->mvid = NULL;
@@ -1264,7 +1264,7 @@ afs_FlushActiveVcaches(register afs_int32 doflocks)
     register int i;
     register struct afs_conn *tc;
     register afs_int32 code;
-    register struct AFS_UCRED *cred = NULL;
+    AFS_UCRED *cred = NULL;
     struct vrequest treq, ureq;
     struct AFSVolSync tsync;
     int didCore;
@@ -1336,7 +1336,7 @@ afs_FlushActiveVcaches(register afs_int32 doflocks)
 		if (tvc->f.states & CCore) {
 		    tvc->f.states &= ~CCore;
 		    /* XXXX Find better place-holder for cred XXXX */
-		    cred = (struct AFS_UCRED *)tvc->linkData;
+		    cred = (AFS_UCRED *)tvc->linkData;
 		    tvc->linkData = NULL;	/* XXX */
 		    afs_InitReq(&ureq, cred);
 		    afs_Trace2(afs_iclSetp, CM_TRACE_ACTCCORE,
@@ -1672,12 +1672,12 @@ int afs_WriteVCacheDiscon(register struct vcache *avc,
 
 	if (astatus->Mask & AFS_SETOWNER) {
 		printf("Not allowed yet. \n");
-		//avc->f.m.Owner = astatus->Owner;
+		/*avc->f.m.Owner = astatus->Owner;*/
 	}
 
 	if (astatus->Mask & AFS_SETGROUP) {
 		printf("Not allowed yet. \n");
-		//avc->f.m.Group =  astatus->Group;
+		/*avc->f.m.Group =  astatus->Group;*/
 	}
 
 	if (astatus->Mask & AFS_SETMODE) {
@@ -2864,8 +2864,8 @@ afs_PutVCache(register struct vcache *avc)
  *
  * \note avc must be write locked on entry
  */
-void 
-afs_ResetVCache(struct vcache *avc, struct AFS_UCRED *acred) {
+void
+afs_ResetVCache(struct vcache *avc, AFS_UCRED *acred) {
     ObtainWriteLock(&afs_xcbhash, 456);
     afs_DequeueCallback(avc);
     avc->f.states &= ~(CStatd | CDirty);    /* next reference will re-stat */
@@ -3233,7 +3233,7 @@ afs_vcacheInit(int astatSize)
     freeVCList = NULL;
 #endif
 
-    RWLOCK_INIT(&afs_xvcache, "afs_xvcache");
+    AFS_RWLOCK_INIT(&afs_xvcache, "afs_xvcache");
     LOCK_INIT(&afs_xvcb, "afs_xvcb");
 
 #if !defined(AFS_OSF_ENV) && !defined(AFS_LINUX22_ENV)
@@ -3281,11 +3281,12 @@ void
 shutdown_vcache(void)
 {
     int i;
-    struct afs_cbr *tsp, *nsp;
+    struct afs_cbr *tsp;
     /*
-     * XXX We may potentially miss some of the vcaches because if when there're no
-     * free vcache entries and all the vcache entries are active ones then we allocate
-     * an additional one - admittedly we almost never had that occur.
+     * XXX We may potentially miss some of the vcaches because if when
+     * there are no free vcache entries and all the vcache entries are active
+     * ones then we allocate an additional one - admittedly we almost never
+     * had that occur.
      */
 
     {
@@ -3370,14 +3371,14 @@ shutdown_vcache(void)
 #if !defined(AFS_OSF_ENV) && !defined(AFS_LINUX22_ENV)
     freeVCList = Initial_freeVCList = 0;
 #endif
-    RWLOCK_INIT(&afs_xvcache, "afs_xvcache");
+    AFS_RWLOCK_INIT(&afs_xvcache, "afs_xvcache");
     LOCK_INIT(&afs_xvcb, "afs_xvcb");
     QInit(&VLRU);
     for(i = 0; i < VCSIZE; ++i)
 	QInit(&afs_vhashTV[i]);
 }
 
-void afs_DisconGiveUpCallbacks() {
+void afs_DisconGiveUpCallbacks(void) {
     int i;
     struct vcache *tvc;
     int nq=0;
@@ -3409,7 +3410,7 @@ void afs_DisconGiveUpCallbacks() {
  * disconnected mode to tidy up during reconnection
  *
  */
-void afs_ClearAllStatdFlag() {
+void afs_ClearAllStatdFlag(void) {
     int i;
     struct vcache *tvc;
    
