@@ -61,6 +61,9 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
+#ifdef IGNORE_SOME_GCC_WARNINGS
+# pragma GCC diagnostic warning "-Wdeprecated-declarations"
+#endif
 
 #define VFS 1
 
@@ -138,6 +141,7 @@
 #include <ctype.h>
 #include <afs/afssyscalls.h>
 #include <afs/afsutil.h>
+#include <afs/sys_prototypes.h>
 
 #ifdef AFS_SGI61_ENV
 #include <unistd.h>
@@ -619,7 +623,8 @@ ParseCacheInfoFile(void)
 int
 PartSizeOverflow(char *path, int cs)
 {
-    int bsize = -1, totalblks, mint;
+  int bsize = -1;
+  afs_int64 totalblks, mint;
 #if AFS_HAVE_STATVFS
     struct statvfs statbuf;
 
@@ -654,7 +659,7 @@ PartSizeOverflow(char *path, int cs)
     bsize = statbuf.f_bsize;
 #endif
     if (bsize == -1)
-	return 0;		/* sucess */
+	return 0;		/* success */
 
     /* now free and totalblks are in fragment units, but we want them in 1K units */
     if (bsize >= 1024) {
@@ -666,7 +671,7 @@ PartSizeOverflow(char *path, int cs)
     mint = totalblks / 100 * 95;
     if (cs > mint) {
 	printf
-	    ("Cache size (%d) must be less than 95%% of partition size (which is %d). Lower cache size\n",
+	    ("Cache size (%d) must be less than 95%% of partition size (which is %lld). Lower cache size\n",
 	     cs, mint);
 	return 1;
     }
@@ -1522,7 +1527,9 @@ mainproc(struct cmd_syndesc *as, void *arock)
     static char rn[] = "afsd";	/*Name of this routine */
     afs_int32 code;		/*Result of fork() */
     int i;
+#ifndef AFS_CACHE_VNODE_PATH
     int currVFile;		/*Current AFS cache file number passed in */
+#endif
     int mountFlags;		/*Flags passed to mount() */
     int lookupResult;		/*Result of GetLocalCellName() */
     int cacheIteration;		/*How many times through cache verification */
@@ -2646,8 +2653,9 @@ call_syscall(long param1, long param2, long param3, long param4, long param5,
     struct afssysargs syscall_data;
     void *ioctldata;
     int fd = open(SYSCALL_DEV_FNAME,O_RDWR);
-    int syscallnum, is64 = 0;
+    int syscallnum;
 #ifdef AFS_DARWIN100_ENV
+    int is64 = 0;
     struct afssysargs64 syscall64_data;
     if (sizeof(param1) == 8) {
 	syscallnum = VIOC_SYSCALL64;
