@@ -21,12 +21,11 @@
 #include <afs/param.h>
 #include <string.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/afsmonitor/afsmon-output.c,v 1.10.2.1 2007/10/30 15:16:36 shadow Exp $");
 
 #include <afs/xstat_fs.h>
 #include <afs/xstat_cm.h>
 
+#include "afsmonitor.h"
 
 
 /* Extern Variables */
@@ -34,8 +33,6 @@ extern int afsmon_debug;	/* debugging on ? */
 extern FILE *debugFD;		/* debug file FD */
 extern char errMsg[256];	/* error message buffer */
 
-extern int afsmon_Exit();	/* exit routine */
-
 static FILE *fs_outFD;		/* fs output file descriptor */
 static FILE *cm_outFD;		/* cm output file descriptor */
 
@@ -111,9 +108,7 @@ static char *xferOpNames[] = {
  *------------------------------------------------------------------------*/
 
 void
-Print_fs_OverallPerfInfo(a_ovP)
-     struct afs_PerfStats *a_ovP;
-
+Print_fs_OverallPerfInfo(struct afs_PerfStats *a_ovP)
 {				/*Print_fs_OverallPerfInfo */
 
     fprintf(fs_outFD, "\t%10d numPerfCalls\n\n", a_ovP->numPerfCalls);
@@ -254,18 +249,15 @@ Print_fs_OverallPerfInfo(a_ovP)
  *------------------------------------------------------------------------*/
 
 void
-Print_fs_OpTiming(a_opIdx, a_opTimeP)
-     int a_opIdx;
-     struct fs_stats_opTimingData *a_opTimeP;
-
+Print_fs_OpTiming(int a_opIdx, struct fs_stats_opTimingData *a_opTimeP)
 {				/*Print_fs_OpTiming */
 
     fprintf(fs_outFD,
-	    "%15s: %d ops (%d OK); sum=%d.%06d, min=%d.%06d, max=%d.%06d\n",
+	    "%15s: %d ops (%d OK); sum=%ld.%06ld, min=%ld.%06ld, max=%ld.%06ld\n",
 	    fsOpNames[a_opIdx], a_opTimeP->numOps, a_opTimeP->numSuccesses,
-	    a_opTimeP->sumTime.tv_sec, a_opTimeP->sumTime.tv_usec,
-	    a_opTimeP->minTime.tv_sec, a_opTimeP->minTime.tv_usec,
-	    a_opTimeP->maxTime.tv_sec, a_opTimeP->maxTime.tv_usec);
+	    (long)a_opTimeP->sumTime.tv_sec, (long)a_opTimeP->sumTime.tv_usec,
+	    (long)a_opTimeP->minTime.tv_sec, (long)a_opTimeP->minTime.tv_usec,
+	    (long)a_opTimeP->maxTime.tv_sec, (long)a_opTimeP->maxTime.tv_usec);
 
 }				/*Print_fs_OpTiming */
 
@@ -291,18 +283,15 @@ Print_fs_OpTiming(a_opIdx, a_opTimeP)
  *------------------------------------------------------------------------*/
 
 void
-Print_fs_XferTiming(a_opIdx, a_xferP)
-     int a_opIdx;
-     struct fs_stats_xferData *a_xferP;
-
+Print_fs_XferTiming(int a_opIdx, struct fs_stats_xferData *a_xferP)
 {				/*Print_fs_XferTiming */
 
     fprintf(fs_outFD,
-	    "%s: %d xfers (%d OK), time sum=%d.%06d, min=%d.%06d, max=%d.%06d\n",
+	    "%s: %d xfers (%d OK), time sum=%ld.%06ld, min=%ld.%06ld, max=%ld.%06ld\n",
 	    xferOpNames[a_opIdx], a_xferP->numXfers, a_xferP->numSuccesses,
-	    a_xferP->sumTime.tv_sec, a_xferP->sumTime.tv_usec,
-	    a_xferP->minTime.tv_sec, a_xferP->minTime.tv_usec,
-	    a_xferP->maxTime.tv_sec, a_xferP->maxTime.tv_usec);
+	    (long)a_xferP->sumTime.tv_sec, (long)a_xferP->sumTime.tv_usec,
+	    (long)a_xferP->minTime.tv_sec, (long)a_xferP->minTime.tv_usec,
+	    (long)a_xferP->maxTime.tv_sec, (long)a_xferP->maxTime.tv_usec);
     fprintf(fs_outFD, "\t[bytes: sum=%d, min=%d, max=%d]\n",
 	    a_xferP->sumBytes, a_xferP->minBytes, a_xferP->maxBytes);
     fprintf(fs_outFD,
@@ -334,14 +323,12 @@ Print_fs_XferTiming(a_opIdx, a_xferP)
  *------------------------------------------------------------------------*/
 
 void
-Print_fs_DetailedPerfInfo(a_detP)
-     struct fs_stats_DetailedStats *a_detP;
-
+Print_fs_DetailedPerfInfo(struct fs_stats_DetailedStats *a_detP)
 {				/*Print_fs_DetailedPerfInfo */
 
     int currIdx;		/*Loop variable */
 
-    fprintf(fs_outFD, "\t%10d epoch\n", a_detP->epoch);
+    fprintf(fs_outFD, "\t%10ld epoch\n", (long)a_detP->epoch.tv_sec);
 
     for (currIdx = 0; currIdx < FS_STATS_NUM_RPC_OPS; currIdx++)
 	Print_fs_OpTiming(currIdx, &(a_detP->rpcOpTimes[currIdx]));
@@ -373,11 +360,8 @@ Print_fs_DetailedPerfInfo(a_detP)
  *------------------------------------------------------------------------*/
 
 void
-Print_fs_FullPerfInfo(a_fs_Results)
-     struct xstat_fs_ProbeResults *a_fs_Results;	/* ptr to fs results */
+Print_fs_FullPerfInfo(struct xstat_fs_ProbeResults *a_fs_Results)
 {				/*Print_fs_FullPerfInfo */
-
-    static char rn[] = "Print_fs_FullPerfInfo";	/*Routine name */
     static afs_int32 fullPerfLongs = (sizeof(struct fs_stats_FullPerfStats) >> 2);	/*Correct # longs to rcv */
     afs_int32 numLongs;		/*# longwords received */
     struct fs_stats_FullPerfStats *fullPerfP;	/*Ptr to full perf stats */
@@ -432,9 +416,8 @@ Print_fs_FullPerfInfo(a_fs_Results)
  *	As advertised.
  *------------------------------------------------------------------------*/
 int
-afsmon_fsOutput(a_outfile, a_detOutput)
-     char *a_outfile;		/* ptr to output file name */
-     int a_detOutput;		/* detailed output ? */
+afsmon_fsOutput(char *a_outfile,	/* ptr to output file name */
+		int a_detOutput)	/* detailed output ? */
 {
 
     static char rn[] = "afsmon_fsOutput";	/* routine name */
@@ -525,9 +508,7 @@ afsmon_fsOutput(a_outfile, a_detOutput)
  *------------------------------------------------------------------------*/
 
 void
-Print_cm_UpDownStats(a_upDownP)
-     struct afs_stats_SrvUpDownInfo *a_upDownP;	/*Ptr to server up/down info */
-
+Print_cm_UpDownStats(struct afs_stats_SrvUpDownInfo *a_upDownP)	/*Ptr to server up/down info */
 {				/*Print_cm_UpDownStats */
 
     /*
@@ -606,9 +587,7 @@ Print_cm_UpDownStats(a_upDownP)
  *------------------------------------------------------------------------*/
 
 void
-Print_cm_OverallPerfInfo(a_ovP)
-     struct afs_stats_CMPerf *a_ovP;
-
+Print_cm_OverallPerfInfo(struct afs_stats_CMPerf *a_ovP)
 {				/*Print_cm_OverallPerfInfo */
 
     fprintf(cm_outFD, "\t%10d numPerfCalls\n", a_ovP->numPerfCalls);
@@ -697,10 +676,8 @@ Print_cm_OverallPerfInfo(a_ovP)
  *------------------------------------------------------------------------*/
 
 void
-Print_cm_PerfInfo()
+Print_cm_PerfInfo(void)
 {				/*Print_cm_PerfInfo */
-
-    static char rn[] = "Print_cm_PerfInfo";	/*Routine name */
     static afs_int32 perfLongs = (sizeof(struct afs_stats_CMPerf) >> 2);	/*Correct # longs to rcv */
     afs_int32 numLongs;		/*# longwords received */
     struct afs_stats_CMPerf *perfP;	/*Ptr to performance stats */
@@ -754,19 +731,16 @@ Print_cm_PerfInfo()
  *------------------------------------------------------------------------*/
 
 void
-Print_cm_OpTiming(a_opIdx, a_opNames, a_opTimeP)
-     int a_opIdx;
-     char *a_opNames[];
-     struct afs_stats_opTimingData *a_opTimeP;
-
+Print_cm_OpTiming(int a_opIdx, char *a_opNames[],
+		  struct afs_stats_opTimingData *a_opTimeP)
 {				/*Print_cm_OpTiming */
 
     fprintf(cm_outFD,
-	    "%15s: %d ops (%d OK); sum=%d.%06d, min=%d.%06d, max=%d.%06d\n",
+	    "%15s: %d ops (%d OK); sum=%ld.%06ld, min=%ld.%06ld, max=%ld.%06ld\n",
 	    a_opNames[a_opIdx], a_opTimeP->numOps, a_opTimeP->numSuccesses,
-	    a_opTimeP->sumTime.tv_sec, a_opTimeP->sumTime.tv_usec,
-	    a_opTimeP->minTime.tv_sec, a_opTimeP->minTime.tv_usec,
-	    a_opTimeP->maxTime.tv_sec, a_opTimeP->maxTime.tv_usec);
+	    (long)a_opTimeP->sumTime.tv_sec, (long)a_opTimeP->sumTime.tv_usec,
+	    (long)a_opTimeP->minTime.tv_sec, (long)a_opTimeP->minTime.tv_usec,
+	    (long)a_opTimeP->maxTime.tv_sec, (long)a_opTimeP->maxTime.tv_usec);
 
 }				/*Print_cm_OpTiming */
 
@@ -792,19 +766,16 @@ Print_cm_OpTiming(a_opIdx, a_opNames, a_opTimeP)
  *------------------------------------------------------------------------*/
 
 void
-Print_cm_XferTiming(a_opIdx, a_opNames, a_xferP)
-     int a_opIdx;
-     char *a_opNames[];
-     struct afs_stats_xferData *a_xferP;
-
+Print_cm_XferTiming(int a_opIdx, char *a_opNames[], 
+		    struct afs_stats_xferData *a_xferP)
 {				/*Print_cm_XferTiming */
 
     fprintf(cm_outFD,
-	    "%s: %d xfers (%d OK), time sum=%d.%06d, min=%d.%06d, max=%d.%06d\n",
+	    "%s: %d xfers (%d OK), time sum=%ld.%06ld, min=%ld.%06ld, max=%ld.%06ld\n",
 	    a_opNames[a_opIdx], a_xferP->numXfers, a_xferP->numSuccesses,
-	    a_xferP->sumTime.tv_sec, a_xferP->sumTime.tv_usec,
-	    a_xferP->minTime.tv_sec, a_xferP->minTime.tv_usec,
-	    a_xferP->maxTime.tv_sec, a_xferP->maxTime.tv_usec);
+	    (long)a_xferP->sumTime.tv_sec, (long)a_xferP->sumTime.tv_usec,
+	    (long)a_xferP->minTime.tv_sec, (long)a_xferP->minTime.tv_usec,
+	    (long)a_xferP->maxTime.tv_sec, (long)a_xferP->maxTime.tv_usec);
     fprintf(cm_outFD, "\t[bytes: sum=%d, min=%d, max=%d]\n",
 	    a_xferP->sumBytes, a_xferP->minBytes, a_xferP->maxBytes);
     fprintf(cm_outFD,
@@ -838,11 +809,8 @@ Print_cm_XferTiming(a_opIdx, a_opNames, a_xferP)
  *------------------------------------------------------------------------*/
 
 void
-Print_cm_ErrInfo(a_opIdx, a_opNames, a_opErrP)
-     int a_opIdx;
-     char *a_opNames[];
-     struct afs_stats_RPCErrors *a_opErrP;
-
+Print_cm_ErrInfo(int a_opIdx, char *a_opNames[],
+		 struct afs_stats_RPCErrors *a_opErrP)
 {				/*Print_cm_ErrInfo */
 
     fprintf(cm_outFD,
@@ -874,9 +842,7 @@ Print_cm_ErrInfo(a_opIdx, a_opNames, a_opErrP)
  *------------------------------------------------------------------------*/
 
 void
-Print_cm_RPCPerfInfo(a_rpcP)
-     struct afs_stats_RPCOpInfo *a_rpcP;
-
+Print_cm_RPCPerfInfo(struct afs_stats_RPCOpInfo *a_rpcP)
 {				/*Print_cm_RPCPerfInfo */
 
     int currIdx;		/*Loop variable */
@@ -924,10 +890,9 @@ Print_cm_RPCPerfInfo(a_rpcP)
  *------------------------------------------------------------------------*/
 
 void
-Print_cm_FullPerfInfo()
+Print_cm_FullPerfInfo(void)
 {				/*Print_cm_FullPerfInfo */
 
-    static char rn[] = "Print_cm_FullPerfInfo";	/* routine name */
     struct afs_stats_AuthentInfo *authentP;	/*Ptr to authentication stats */
     struct afs_stats_AccessInfo *accessinfP;	/*Ptr to access stats */
     static afs_int32 fullPerfLongs = (sizeof(struct afs_stats_CMFullPerf) >> 2);	/*Correct #longs */
@@ -1017,9 +982,8 @@ Print_cm_FullPerfInfo()
  *	As advertised.
  *------------------------------------------------------------------------*/
 int
-afsmon_cmOutput(a_outfile, a_detOutput)
-     char *a_outfile;		/* ptr to output file name */
-     int a_detOutput;		/* detailed output ? */
+afsmon_cmOutput(char *a_outfile,		/* ptr to output file name */
+		int a_detOutput)		/* detailed output ? */
 {
 
     static char rn[] = "afsmon_cmOutput";	/* routine name */
