@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/auth/cellconfig.c,v 1.47.2.17 2009/03/16 13:17:43 shadow Exp $");
 
 #include <afs/stds.h>
 #include <afs/pthread_glock.h>
@@ -20,6 +18,8 @@ RCSID
 #include "afsincludes.h"
 #include "des/des.h"
 #include "rx/rxkad.h"
+#include <netdb.h>
+#include <ctype.h>
 #else /* UKERNEL */
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
@@ -33,6 +33,7 @@ RCSID
 #include <netdb.h>
 #include <sys/file.h>
 #include <sys/time.h>
+#include <ctype.h>
 #ifdef AFS_AFSDB_ENV
 #include <arpa/nameser.h>
 #ifdef HAVE_ARPA_NAMESER_COMPAT_H
@@ -61,6 +62,8 @@ RCSID
 #include "keys.h"
 #ifdef AFS_NT40_ENV
 #ifdef AFS_AFSDB_ENV
+#include <cm.h>
+#include <cm_config.h>
 /* cm_dns.h depends on cellconfig.h */
 #include <cm_nls.h>
 #include <cm_dns.h>
@@ -87,9 +90,9 @@ static struct afsconf_servPair serviceTable[] = {
 
 /* Prototypes */
 static afs_int32 afsconf_FindService(register const char *aname);
-static int TrimLine(char *abuffer);
-#ifdef AFS_NT40_ENV
+static int TrimLine(char *abuffer, int abufsize);
 static int IsClientConfigDirectory(const char *path);
+#ifdef AFS_NT40_ENV
 static int GetCellNT(struct afsconf_dir *adir);
 #endif
 static int afsconf_Check(register struct afsconf_dir *adir);
@@ -234,7 +237,7 @@ afsconf_FindService(register const char *aname)
 #if     defined(AFS_OSF_ENV) 
     ts = getservbyname(aname, "");
 #else
-    ts = getservbyname(aname, NULL);
+    ts = (struct servent *) getservbyname(aname, NULL);
 #endif
     if (ts) {
 	/* we found it in /etc/services, so we use this value */
@@ -251,7 +254,7 @@ afsconf_FindService(register const char *aname)
 }
 
 static int
-TrimLine(char *abuffer)
+TrimLine(char *abuffer, int abufsize)
 {
     char tbuffer[256];
     register char *tp;
@@ -263,25 +266,30 @@ TrimLine(char *abuffer)
 	    break;
 	tp++;
     }
-    strcpy(tbuffer, tp);
-    strcpy(abuffer, tbuffer);
+    strlcpy(tbuffer, tp, sizeof tbuffer);
+    strlcpy(abuffer, tbuffer, abufsize);
     return 0;
 }
 
-#ifdef AFS_NT40_ENV
 /*
  * IsClientConfigDirectory() -- determine if path matches well-known
  *     client configuration directory.
  */
+#ifdef AFS_NT40_ENV
+#define IS_SEP(x) ((x) == '\\' || (x) == '/')
+#else /* AFS_NT40_ENV */
+#define IS_SEP(x) ((x) == '/')
+#endif /* AFS_NT40_ENV */
 static int
 IsClientConfigDirectory(const char *path)
 {
     const char *cdir = AFSDIR_CLIENT_ETC_DIRPATH;
-    int i;
+    int i, cc, pc;
 
     for (i = 0; cdir[i] != '\0' && path[i] != '\0'; i++) {
-	int cc = tolower(cdir[i]);
-	int pc = tolower(path[i]);
+#ifdef AFS_NT40_ENV
+	cc = tolower(cdir[i]);
+	pc = tolower(path[i]);
 
 	if (cc == '\\') {
 	    cc = '/';
@@ -289,25 +297,28 @@ IsClientConfigDirectory(const char *path)
 	if (pc == '\\') {
 	    pc = '/';
 	}
-	if (cc != pc) {
+#else /* AFS_NT40_ENV */
+	cc = cdir[i];
+	pc = path[i];
+#endif /* AFS_NT40_ENV */
+        if (cc != pc) {
 	    return 0;
 	}
     }
 
     /* hit end of one or both; allow mismatch in existence of trailing slash */
     if (cdir[i] != '\0') {
-	if ((cdir[i] != '\\' && cdir[i] != '/') || (cdir[i + 1] != '\0')) {
+	if (!IS_SEP(cdir[i]) || (cdir[i + 1] != '\0')) {
 	    return 0;
 	}
     }
     if (path[i] != '\0') {
-	if ((path[i] != '\\' && path[i] != '/') || (path[i + 1] != '\0')) {
+	if (!IS_SEP(path[i]) || (path[i + 1] != '\0')) {
 	    return 0;
 	}
     }
     return 1;
 }
-#endif /* AFS_NT40_ENV */
 
 
 static int
@@ -413,8 +424,7 @@ afsconf_Open(register const char *adir)
     /* zero structure and fill in name; rest is done by internal routine */
     tdir = (struct afsconf_dir *)malloc(sizeof(struct afsconf_dir));
     memset(tdir, 0, sizeof(struct afsconf_dir));
-    tdir->name = (char *)malloc(strlen(adir) + 1);
-    strcpy(tdir->name, adir);
+    tdir->name = strdup(adir);
 
     code = afsconf_OpenInternal(tdir, 0, 0);
     if (code) {
@@ -466,8 +476,7 @@ afsconf_Open(register const char *adir)
 	    }
 	    afsconf_path = afs_confdir;
 	}
-	tdir->name = (char *)malloc(strlen(afsconf_path) + 1);
-	strcpy(tdir->name, afsconf_path);
+	tdir->name = strdup(afsconf_path);
 	code = afsconf_OpenInternal(tdir, 0, 0);
 	if (code) {
 	    free(tdir->name);
@@ -525,6 +534,69 @@ GetCellNT(struct afsconf_dir *adir)
 	return GetCellUnix(adir);
     }
 }
+
+/* The following procedures and structs are used on Windows only
+ * to enumerate the Cell information distributed within the 
+ * Windows registry.  (See src/WINNT/afsd/cm_config.c)
+ */
+typedef struct _cm_enumCellRegistry {
+    afs_uint32 client;  /* non-zero if client query */
+    struct afsconf_dir *adir;
+} cm_enumCellRegistry_t;
+
+static long
+cm_serverConfigProc(void *rockp, struct sockaddr_in *addrp, 
+                    char *hostNamep, unsigned short rank)
+{
+    struct afsconf_cell *cellInfop = (struct afsconf_cell *)rockp;
+
+    if (cellInfop->numServers == MAXHOSTSPERCELL)
+        return 0;
+
+    cellInfop->hostAddr[cellInfop->numServers] = *addrp;
+    strncpy(cellInfop->hostName[cellInfop->numServers], hostNamep, MAXHOSTCHARS);
+    cellInfop->hostName[cellInfop->numServers][MAXHOSTCHARS-1] = '\0';
+    cellInfop->numServers++;
+
+    return 0;
+}
+
+static long
+cm_enumCellRegistryProc(void *rockp, char * cellNamep)
+{
+    long code;
+    cm_enumCellRegistry_t *enump = (cm_enumCellRegistry_t *)rockp;
+    char linkedName[256] = "";
+    int timeout = 0;
+    struct afsconf_entry *newEntry;
+
+
+    newEntry = malloc(sizeof(struct afsconf_entry));
+    if (newEntry == NULL)
+        return ENOMEM;
+    newEntry->cellInfo.numServers = 0;
+
+    code = cm_SearchCellRegistry(enump->client, cellNamep, NULL, linkedName, cm_serverConfigProc, &newEntry->cellInfo);
+    if (code == CM_ERROR_FORCE_DNS_LOOKUP)
+        code = cm_SearchCellByDNS(cellNamep, NULL, &timeout, cm_serverConfigProc, &newEntry->cellInfo);
+
+    if (code == 0) {
+        strncpy(newEntry->cellInfo.name, cellNamep, MAXCELLCHARS);
+        newEntry->cellInfo.name[MAXCELLCHARS-1];
+        if (linkedName[0])
+            newEntry->cellInfo.linkedCell = strdup(linkedName);
+        else
+            newEntry->cellInfo.linkedCell = NULL;
+        newEntry->cellInfo.timeout = timeout;
+        newEntry->cellInfo.flags = 0;
+
+        newEntry->next = enump->adir->entries;
+	enump->adir->entries = newEntry;
+    } else {
+        free(newEntry);
+    }
+    return code;
+}       
 #endif /* AFS_NT40_ENV */
 
 
@@ -540,10 +612,14 @@ afsconf_OpenInternal(register struct afsconf_dir *adir, char *cell,
     afs_int32 i;
     char tbuffer[256], tbuf1[256];
     struct stat tstat;
+#ifdef AFS_NT40_ENV
+    cm_enumCellRegistry_t enumCellRegistry = {0, 0};
+#endif /* AFS_NT40_ENV */
 
     /* figure out the local cell name */
 #ifdef AFS_NT40_ENV
     i = GetCellNT(adir);
+    enumCellRegistry.adir = adir;
 #else
     i = GetCellUnix(adir);
 #endif
@@ -564,6 +640,9 @@ afsconf_OpenInternal(register struct afsconf_dir *adir, char *cell,
     if (IsClientConfigDirectory(adir->name)) {
 	/* NT client config dir */
 	char *p;
+
+        enumCellRegistry.client = 1;
+
 	if (!afssw_GetClientCellServDBDir(&p)) {
 	    strcompose(tbuffer, sizeof(tbuffer), p, "/",
 		       AFSDIR_CELLSERVDB_FILE_NTCLIENT, NULL);
@@ -594,16 +673,29 @@ afsconf_OpenInternal(register struct afsconf_dir *adir, char *cell,
 	adir->timeRead = 0;
     }
 
-    strcpy(tbuf1, tbuffer);
+    strlcpy(tbuf1, tbuffer, sizeof tbuf1);
     tf = fopen(tbuffer, "r");
     if (!tf) {
 	return -1;
     }
+
+    /* The CellServDB file is now open.  
+     * The following code parses the contents of the 
+     * file and creates a list with the first cell entry
+     * in the CellServDB file at the end of the list.
+     * 
+     * No checking is performed for duplicates.
+     * The side effects of this process are that duplicate
+     * entries appended to the end of the CellServDB file
+     * take precedence and are found in a shorter period 
+     * of time.
+     */
+
     while (1) {
 	tp = fgets(tbuffer, sizeof(tbuffer), tf);
 	if (!tp)
 	    break;
-	TrimLine(tbuffer);	/* remove white space */
+	TrimLine(tbuffer, sizeof tbuffer);	/* remove white space */
 	if (tbuffer[0] == 0 || tbuffer[0] == '\n')
 	    continue;		/* empty line */
 	if (tbuffer[0] == '>') {
@@ -626,11 +718,8 @@ afsconf_OpenInternal(register struct afsconf_dir *adir, char *cell,
 		free(curEntry);
 		return -1;
 	    }
-	    if (linkedcell[0] != '\0') {
-		curEntry->cellInfo.linkedCell =
-		    (char *)malloc(strlen(linkedcell) + 1);
-		strcpy(curEntry->cellInfo.linkedCell, linkedcell);
-	    }
+	    if (linkedcell[0] != '\0')
+		curEntry->cellInfo.linkedCell = strdup(linkedcell);
 	} else {
 	    /* new host in the current cell */
 	    if (!curEntry) {
@@ -639,31 +728,41 @@ afsconf_OpenInternal(register struct afsconf_dir *adir, char *cell,
 		return -1;
 	    }
 	    i = curEntry->cellInfo.numServers;
-	    if (cell && !strcmp(cell, curEntry->cellInfo.name))
-		code =
-		    ParseHostLine(tbuffer, &curEntry->cellInfo.hostAddr[i],
-				  curEntry->cellInfo.hostName[i], &clones[i]);
-	    else
-		code =
-		    ParseHostLine(tbuffer, &curEntry->cellInfo.hostAddr[i],
-				  curEntry->cellInfo.hostName[i], 0);
-	    if (code) {
-		if (code == AFSCONF_SYNTAX) {
-		    for (bp = tbuffer; *bp != '\n'; bp++) {	/* Take out the <cr> from the buffer */
-			if (!*bp)
-			    break;
+	    if (i < MAXHOSTSPERCELL) {
+		if (cell && !strcmp(cell, curEntry->cellInfo.name))
+		    code =
+			ParseHostLine(tbuffer, 
+				      &curEntry->cellInfo.hostAddr[i],
+				      curEntry->cellInfo.hostName[i], 
+				      &clones[i]);
+		else
+		    code =
+			ParseHostLine(tbuffer, 
+				      &curEntry->cellInfo.hostAddr[i],
+				      curEntry->cellInfo.hostName[i], 0);
+
+		if (code) {
+		    if (code == AFSCONF_SYNTAX) {
+			for (bp = tbuffer; *bp != '\n'; bp++) {	/* Take out the <cr> from the buffer */
+			    if (!*bp)
+				break;
+			}
+			*bp = '\0';
+			fprintf(stderr,
+				"Can't properly parse host line \"%s\" in configuration file %s\n",
+				tbuffer, tbuf1);
 		    }
-		    *bp = '\0';
-		    fprintf(stderr,
-			    "Can't properly parse host line \"%s\" in configuration file %s\n",
-			    tbuffer, tbuf1);
+		    free(curEntry);
+		    fclose(tf);
+		    afsconf_CloseInternal(adir);
+		    return -1;
 		}
-		free(curEntry);
-		fclose(tf);
-		afsconf_CloseInternal(adir);
-		return -1;
+		curEntry->cellInfo.numServers = ++i;
+	    } else {
+		fprintf(stderr,
+			"Too many hosts for cell %s in configuration file %s\n", 
+			curEntry->cellInfo.name, tbuf1);
 	    }
-	    curEntry->cellInfo.numServers = ++i;
 	}
     }
     fclose(tf);			/* close the file now */
@@ -674,6 +773,18 @@ afsconf_OpenInternal(register struct afsconf_dir *adir, char *cell,
 	adir->entries = curEntry;
     }
 
+#ifdef AFS_NT40_ENV
+     /* 
+      * Windows maintains a CellServDB list in the Registry
+      * that supercedes the contents of the CellServDB file.
+      * Prepending these entries to the head of the list 
+      * is sufficient to enforce the precedence.
+      */
+     cm_EnumerateCellRegistry( enumCellRegistry.client,
+                               cm_enumCellRegistryProc,
+                               &enumCellRegistry);
+#endif /* AFS_NT40_ENV */
+
     /* Read in the alias list */
     strcompose(tbuffer, 256, adir->name, "/", AFSDIR_CELLALIAS_FILE, NULL);
 
@@ -684,7 +795,7 @@ afsconf_OpenInternal(register struct afsconf_dir *adir, char *cell,
 	tp = fgets(tbuffer, sizeof(tbuffer), tf);
 	if (!tp)
 	    break;
-	TrimLine(tbuffer);	/* remove white space */
+	TrimLine(tbuffer, sizeof tbuffer);	/* remove white space */
 
 	if (tbuffer[0] == '\0' || tbuffer[0] == '\n' || tbuffer[0] == '#')
 	    continue;		/* empty line */
@@ -709,8 +820,8 @@ afsconf_OpenInternal(register struct afsconf_dir *adir, char *cell,
 	curAlias = malloc(sizeof(*curAlias));
 	memset(curAlias, 0, sizeof(*curAlias));
 
-	strcpy(curAlias->aliasInfo.aliasName, aliasPtr);
-	strcpy(curAlias->aliasInfo.realName, tbuffer);
+	strlcpy(curAlias->aliasInfo.aliasName, aliasPtr, sizeof curAlias->aliasInfo.aliasName);
+	strlcpy(curAlias->aliasInfo.realName, tbuffer, sizeof curAlias->aliasInfo.realName);
 
 	curAlias->next = adir->alias_entries;
 	adir->alias_entries = curAlias;
@@ -935,7 +1046,7 @@ afsconf_GetAfsdbInfo(char *acellName, char *aservice,
 		 * right AFSDB type.  Write down the true cell name that
 		 * the resolver gave us above.
 		 */
-		strcpy(realCellName, host);
+		strlcpy(realCellName, host, sizeof realCellName);
 	    }
 
 	    code = dn_expand(answer, answer + len, p + 2, host, sizeof(host));
@@ -993,13 +1104,14 @@ afsconf_GetAfsdbInfo(char *acellName, char *aservice,
     struct afsconf_entry DNSce;
     afs_int32 cellHostAddrs[AFSMAXCELLHOSTS];
     char cellHostNames[AFSMAXCELLHOSTS][MAXHOSTCHARS];
+    unsigned short ipRanks[AFSMAXCELLHOSTS];
     int numServers;
     int rc;
     int ttl;
 
     DNSce.cellInfo.numServers = 0;
     DNSce.next = NULL;
-    rc = getAFSServer(acellName, cellHostAddrs, cellHostNames, &numServers,
+    rc = getAFSServer(acellName, cellHostAddrs, cellHostNames, ipRanks, &numServers,
 		      &ttl);
     /* ignore the ttl here since this code is only called by transitory programs
      * like klog, etc. */
@@ -1018,7 +1130,7 @@ afsconf_GetAfsdbInfo(char *acellName, char *aservice,
     }
 
     acellInfo->numServers = numServers;
-    strcpy(acellInfo->name, acellName);
+    strlcpy(acellInfo->name, acellName, sizeof acellInfo->name);
     if (aservice) {
 	LOCK_GLOBAL_MUTEX;
 	tservice = afsconf_FindService(aservice);
@@ -1112,6 +1224,64 @@ afsconf_GetCellInfo(struct afsconf_dir *adir, char *acellName, char *aservice,
 	    }
 	}
 	acellInfo->timeout = 0;
+
+        /* 
+         * Until we figure out how to separate out ubik server
+         * queries from other server queries, only perform gethostbyname()
+         * lookup on the specified hostnames for the client CellServDB files.
+         */
+        if (IsClientConfigDirectory(adir->name) && 
+            !(acellInfo->flags & AFSCONF_CELL_FLAG_DNS_QUERIED)) {
+            int j;
+            short numServers=0;		                        /*Num active servers for the cell */
+            struct sockaddr_in hostAddr[MAXHOSTSPERCELL];	/*IP addresses for cell's servers */
+            char hostName[MAXHOSTSPERCELL][MAXHOSTCHARS];	/*Names for cell's servers */
+
+            memset(&hostAddr, 0, sizeof(hostAddr));
+            memset(&hostName, 0, sizeof(hostName));
+
+            for ( j=0; j<acellInfo->numServers && numServers < MAXHOSTSPERCELL; j++ ) {
+                struct hostent *he = gethostbyname(acellInfo->hostName[j]);
+                int foundAddr = 0;
+
+                if (he && he->h_addrtype == AF_INET) {
+                    int i;
+                    /* obtain all the valid address from the list */
+                    for (i=0 ; he->h_addr_list[i] && numServers < MAXHOSTSPERCELL; i++) {
+                        /* check to see if this is a new address; if so insert it into the list */
+                        int k, dup;
+                        for (k=0, dup=0; !dup && k < numServers; k++) {
+                            if (hostAddr[k].sin_addr.s_addr == *(u_long *)he->h_addr_list[i])
+                                dup = 1;
+                        }
+                        if (dup)
+                            continue;
+
+                        hostAddr[numServers].sin_family = AF_INET;
+                        hostAddr[numServers].sin_port = acellInfo->hostAddr[0].sin_port;
+#ifdef STRUCT_SOCKADDR_HAS_SA_LEN
+                        hostAddr[numServers].sin_len = sizeof(struct sockaddr_in);
+#endif
+                        memcpy(&hostAddr[numServers].sin_addr.s_addr, he->h_addr_list[i], sizeof(long));
+                        strcpy(hostName[numServers], acellInfo->hostName[j]);
+                        foundAddr = 1;
+                        numServers++;
+                    }
+                }
+                if (!foundAddr) {
+                    hostAddr[numServers] = acellInfo->hostAddr[j];
+                    strcpy(hostName[numServers], acellInfo->hostName[j]);
+                    numServers++;
+                }
+            }
+
+            for (i=0; i<numServers; i++) {
+                acellInfo->hostAddr[i] = hostAddr[i];
+                strcpy(acellInfo->hostName[i], hostName[i]);
+            }
+            acellInfo->numServers = numServers;
+            acellInfo->flags |= AFSCONF_CELL_FLAG_DNS_QUERIED;
+        }
 	UNLOCK_GLOBAL_MUTEX;
 	return 0;
     } else {
