@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/bozo/fsbnodeops.c,v 1.15.2.6 2009/03/19 18:03:51 shadow Exp $");
 
 #include <sys/types.h>
 #include <lwp.h>
@@ -101,7 +99,7 @@ struct fsbnode {
 };
 
 struct bnode * fs_create(char *ainstance, char *afilecmd, char *avolcmd, 
-			 char *asalcmd, char *ascancmd, char *unused);
+			 char *asalcmd, char *ascancmd, char *dummy);
 struct bnode * dafs_create(char *ainstance, char *afilecmd, char *avolcmd, 
 			   char * asalsrvcmd, char *asalcmd, char *ascancmd);
 
@@ -160,7 +158,10 @@ struct bnode_ops dafsbnode_ops = {
  * dropping type information
  */
 
-static_inline struct bnode * fsbnode2bnode(struct fsbnode *abnode) {
+#ifndef AFS_HPUX_ENV
+static_inline 
+#endif
+struct bnode * fsbnode2bnode(struct fsbnode *abnode) {
     return (struct bnode *) abnode;
 }
 
@@ -378,7 +379,7 @@ AppendExecutableExtension(char *cmd)
 
 struct bnode *
 fs_create(char *ainstance, char *afilecmd, char *avolcmd, char *asalcmd,
-	  char *ascancmd, char *unused)
+	  char *ascancmd, char *dummy)
 {
     struct stat tstat;
     register struct fsbnode *te;
