@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/bucoord/vol_sets.c,v 1.11.6.3 2007/04/10 18:39:50 shadow Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -29,18 +27,18 @@ RCSID
 #include <afs/bubasics.h>
 #include "bc.h"
 #include "error_macros.h"
-
+#include "bucoord_internal.h"
+#include "bucoord_prototypes.h"
+    
 /* code to manage volumesets
  * specific to the ubik database implementation
  */
 
-afs_int32 bc_UpdateVolumeSet();
 extern struct bc_config *bc_globalConfig;
 extern struct udbHandleS udbHandle;
 extern char *whoami;
-extern struct bc_volumeSet *bc_FindVolumeSet(struct bc_config *cf, char *name);
-extern void FreeVolumeSet(struct bc_volumeSet *avset);
 
+static int ListVolSet(struct bc_volumeSet *aset);
 
 /* ------------------------------------
  * command level routines
@@ -57,11 +55,10 @@ extern void FreeVolumeSet(struct bc_volumeSet *avset);
  *	parm 3 is volume regexp
  */
 
-bc_AddVolEntryCmd(as, arock)
-     struct cmd_syndesc *as;
-     char *arock;
+int
+bc_AddVolEntryCmd(struct cmd_syndesc *as, void *arock)
 {
-    register afs_int32 code;
+    register int code;
     char *volSetName, *serverName, *partitionName, *volRegExp;
     udbClientTextP ctPtr;
     struct bc_volumeSet *tset;
@@ -129,13 +126,11 @@ bc_AddVolEntryCmd(as, arock)
  *	name of new volume set
  */
 
-afs_int32
-bc_AddVolSetCmd(as, arock)
-     struct cmd_syndesc *as;
-     char *arock;
+int
+bc_AddVolSetCmd(struct cmd_syndesc *as, void *arock)
 {
     /* parm 0 is vol set name */
-    register afs_int32 code;
+    register int code;
     register struct cmd_item *ti;
     udbClientTextP ctPtr;
     afs_int32 flags;
@@ -190,12 +185,10 @@ bc_AddVolSetCmd(as, arock)
  *	parm 1 is entry # (integer, 1 based)
  */
 
-afs_int32
-bc_DeleteVolEntryCmd(as, arock)
-     struct cmd_syndesc *as;
-     char *arock;
+int
+bc_DeleteVolEntryCmd(struct cmd_syndesc *as, void *arock)
 {
-    register afs_int32 code;
+    register int code;
     afs_int32 entry;
     char *vsname;
     udbClientTextP ctPtr;
@@ -279,13 +272,11 @@ bc_DeleteVolEntryCmd(as, arock)
  *	name of volumeset to delete
  */
 
-afs_int32
-bc_DeleteVolSetCmd(as, arock)
-     struct cmd_syndesc *as;
-     char *arock;
+int
+bc_DeleteVolSetCmd(struct cmd_syndesc *as, void *arock)
 {
     /* parm 0 is vol set name */
-    register afs_int32 code;
+    register int code;
     register struct cmd_item *ti;
     udbClientTextP ctPtr;
     afs_int32 c;
@@ -364,13 +355,13 @@ ListVolSet(struct bc_volumeSet *aset)
   *     optional parameter specifies a volumeset name
   */
 
-afs_int32
-bc_ListVolSetCmd(struct cmd_syndesc *as, char *arock)
+int
+bc_ListVolSetCmd(struct cmd_syndesc *as, void *arock)
 {
     /* parm 0 is optional volume set to display */
     register struct bc_volumeSet *tset;
     register struct cmd_item *ti;
-    afs_int32 code = 0;
+    int code = 0;
 
     code = bc_UpdateVolumeSet();
     if (code) {
@@ -379,7 +370,7 @@ bc_ListVolSetCmd(struct cmd_syndesc *as, char *arock)
     }
 
     /* figure out volume set to list */
-    if (ti = as->parms[0].items) {
+    if ((ti = as->parms[0].items)) {
 	/* for each volume set in the command item list */
 	for (; ti; ti = ti->next) {
 	    tset = bc_FindVolumeSet(bc_globalConfig, ti->data);
@@ -409,9 +400,9 @@ bc_ListVolSetCmd(struct cmd_syndesc *as, char *arock)
  * ------------------------------------
  */
 
-bc_ClearVolumeSets()
+int
+bc_ClearVolumeSets(void)
 {
-    struct udbHandleS *uhptr = &udbHandle;
     struct bc_volumeSet *vsPtr, *vsNextPtr, **vsPrev;
 
     extern struct bc_config *bc_globalConfig;
@@ -440,15 +431,14 @@ bc_ClearVolumeSets()
  */
 
 int
-bc_ParseVolumeSet()
+bc_ParseVolumeSet(void)
 {
-    static char rn[] = "bc_ParseVolumeSet";	/*Routine name */
     char tbuffer[1024];		/*Buffer for reading config file */
     char vsname[256];		/*Volume set name */
     char serverName[256];	/*Server name */
     char partName[256];		/*Partition name */
     register struct bc_volumeEntry *tve;	/*Ptr to generated volume spec struct */
-    register struct bc_volumeSet *tvs;	/*Ptr to volume set struct */
+    register struct bc_volumeSet *tvs = NULL;	/*Ptr to volume set struct */
     struct bc_volumeEntry **ppve, *pve;
     struct bc_volumeSet **ppvs, *pvs;
     register afs_int32 code;	/*Generalized return code */
@@ -602,7 +592,8 @@ bc_ParseVolumeSet()
  *	save the current volume set information to disk
  */
 
-bc_SaveVolumeSet()
+int
+bc_SaveVolumeSet(void)
 {
     register afs_int32 code = 0;
     register struct bc_volumeSet *tset;
@@ -663,7 +654,7 @@ bc_SaveVolumeSet()
 }
 
 afs_int32
-bc_UpdateVolumeSet()
+bc_UpdateVolumeSet(void)
 {
     struct udbHandleS *uhptr = &udbHandle;
     udbClientTextP ctPtr;
