@@ -12,8 +12,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/butc/tcprocs.c,v 1.14.6.2 2007/02/09 01:00:20 shadow Exp $");
 
 #include <sys/types.h>
 #include <errno.h>
@@ -27,6 +25,7 @@ RCSID
 #include <rx/rx.h>
 #include <afs/afsint.h>
 #include <stdio.h>
+#include <string.h>
 #include <afs/procmgmt.h>
 #include <afs/assert.h>
 #include <afs/prs_fs.h>
@@ -38,8 +37,16 @@ RCSID
 #include <afs/keys.h>
 #include <ubik.h>
 #include <afs/tcdata.h>
+#include <afs/budb_client.h>
+#include <afs/bucoord_prototypes.h>
 #include "error_macros.h"
 #include "butc_xbsa.h"
+#include "butc_prototypes.h"
+#include "butc_internal.h"
+
+static int CopyDumpDesc(struct tc_dumpDesc *, tc_dumpArray *);
+static int CopyRestoreDesc(struct tc_restoreDesc *, tc_restoreArray *);
+static int CopyTapeSetDesc(struct tc_tapeSet *, struct tc_tapeSet *);
 
 int
 callPermitted(struct rx_call *call)
@@ -138,13 +145,9 @@ STC_LabelTape(struct rx_call *acid, struct tc_tapeLabel *label, afs_uint32 *task
     PROCESS pid;
 #endif
     struct labelTapeIf *ptr;
-    statusP statusPtr;
+    statusP statusPtr = NULL;
     afs_int32 code;
 
-    extern int Labeller();
-    extern statusP createStatusNode();
-    extern afs_int32 allocTaskId();
-
 #ifdef xbsa
     if (CONF_XBSA)
 	return (TC_BADTASK);	/* LabelTape does not apply if XBSA */
@@ -221,9 +224,6 @@ STC_PerformDump(struct rx_call *rxCallId, struct tc_dumpInterface *tcdiPtr, tc_d
 #endif
     afs_int32 code = 0;
 
-    extern statusP createStatusNode();
-    extern Dumper();
-
     if (callPermitted(rxCallId) == 0)
 	return (TC_NOTPERMITTED);
 
@@ -320,9 +320,6 @@ STC_PerformRestore(struct rx_call *acid, char *dumpSetName, tc_restoreArray *are
     PROCESS pid;
 #endif
 
-    extern int Restorer();
-    extern statusP createStatusNode();
-
     if (callPermitted(acid) == 0)
 	return (TC_NOTPERMITTED);
 
@@ -388,8 +385,6 @@ STC_ReadLabel(struct rx_call *acid, struct tc_tapeLabel *label, afs_uint32 *task
 {
     afs_int32 code;
 
-    extern int ReadLabel();
-
 #ifdef xbsa
     if (CONF_XBSA)
 	return (TC_BADTASK);	/* ReadLabel does not apply if XBSA */
@@ -419,10 +414,6 @@ STC_RestoreDb(struct rx_call *rxCall, afs_uint32 *taskId)
     statusP statusPtr;
     afs_int32 code = 0;
 
-    extern afs_int32 restoreDbFromTape();
-    extern statusP createStatusNode();
-    extern afs_int32 allocTaskId();
-
 #ifdef xbsa
     if (CONF_XBSA)
 	return (TC_BADTASK);	/* LabelTape does not apply if XBSA */
@@ -455,11 +446,11 @@ STC_RestoreDb(struct rx_call *rxCall, afs_uint32 *taskId)
 	ERROR_EXIT(code);
 
     AFS_SIGSET_CLEAR();
-    code = pthread_create(&pid, &tattr, restoreDbFromTape, (void *)*taskId);
+    code = pthread_create(&pid, &tattr, restoreDbFromTape, (void *)(intptr_t)*taskId);
     AFS_SIGSET_RESTORE();
 #else
     code =
-	LWP_CreateProcess(restoreDbFromTape, 32768, 1, (void *)*taskId,
+	LWP_CreateProcess(restoreDbFromTape, 32768, 1, (void *)(intptr_t)*taskId,
 			  "Db restore", &pid);
 #endif
 
@@ -486,14 +477,10 @@ STC_SaveDb(struct rx_call *rxCall, Date archiveTime, afs_uint32 *taskId)
 #else
     PROCESS pid;
 #endif
-    statusP statusPtr;
+    statusP statusPtr = NULL;
     afs_int32 code = 0;
     struct saveDbIf *ptr;
 
-    extern afs_int32 saveDbToTape();
-    extern statusP createStatusNode();
-    extern afs_int32 allocTaskId();
-
 #ifdef xbsa
     if (CONF_XBSA)
 	return (TC_BADTASK);	/* LabelTape does not apply if XBSA */
@@ -570,13 +557,9 @@ STC_ScanDumps(struct rx_call *acid, afs_int32 addDbFlag, afs_uint32 *taskId)
     PROCESS pid;
 #endif
     struct scanTapeIf *ptr;
-    statusP statusPtr;
+    statusP statusPtr = NULL;
     afs_int32 code = 0;
 
-    extern afs_int32 ScanDumps();
-    extern afs_int32 allocTaskId();
-    extern statusP createStatusNode();
-
 #ifdef xbsa
     if (CONF_XBSA)
 	return (TC_BADTASK);	/* ScanDumps does not apply if XBSA */
@@ -653,10 +636,10 @@ STC_TCInfo(struct rx_call *acid, struct tc_tcInfo *tciptr)
 afs_int32
 STC_DeleteDump(struct rx_call *acid, afs_uint32 dumpID, afs_uint32 *taskId)
 {
-    struct deleteDumpIf *ptr = 0;
-    statusP statusPtr = 0;
     afs_int32 code = TC_BADTASK;	/* If not compiled -Dxbsa then fail */
 #ifdef xbsa
+    struct deleteDumpIf *ptr = 0;
+    statusP statusPtr = 0;
 #ifdef AFS_PTHREAD_ENV
     pthread_t pid;
     pthread_attr_t tattr;
@@ -665,9 +648,6 @@ STC_DeleteDump(struct rx_call *acid, afs_uint32 dumpID, afs_uint32 *taskId)
     PROCESS pid;
 #endif
 #endif
-    extern afs_int32 DeleteDump();
-    extern statusP createStatusNode();
-    extern afs_int32 allocTaskId();
 
     *taskId = 0;
     if (!CONF_XBSA)
