@@ -14,9 +14,11 @@
 #define AFS_DARWIN_ENV
 #define AFS_DARWIN13_ENV
 #define AFS_DARWIN14_ENV
+#undef  AFS_NONFSTRANS
 #define AFS_NONFSTRANS
 #define AFS_SYSCALL             230
 #define AFS_NAMEI_ENV 1
+#define DARWIN_REFBASE 0
 
 /* File system entry (used if mount.h doesn't define MOUNT_AFS */
 #define AFS_MOUNT_AFS    "afs"
@@ -82,8 +84,10 @@
 #define AFS_USR_DARWIN_ENV
 #define AFS_USR_DARWIN13_ENV
 #define AFS_USR_DARWIN14_ENV
+#undef  AFS_NONFSTRANS
 #define AFS_NONFSTRANS
 #define AFS_SYSCALL             230
+#define DARWIN_REFBASE 0
 
 /* File system entry (used if mount.h doesn't define MOUNT_AFS */
 #define AFS_MOUNT_AFS    "afs"
