@@ -17,6 +17,7 @@
 #define AFS_DARWIN14_ENV
 #define AFS_DARWIN60_ENV
 #define AFS_DARWIN70_ENV
+#undef  AFS_NONFSTRANS
 #define AFS_NONFSTRANS
 #define AFS_SYSCALL             230
 #define AFS_NAMEI_ENV 1
@@ -63,10 +64,11 @@
 #define va_nodeid       va_fileid
 #define vfs_vnodecovered mnt_vnodecovered
 #define direct          dirent
-#define vnode_t         struct vnode
+#define vnode_t         struct vnode *
+#define mount_t         struct mount *
 
-#define VN_RELE(vp)     vrele(((struct vnode *)(vp)))
-#define VN_HOLD(vp)     VREF(((struct vnode *)(vp)))
+//#define VN_RELE(vp)     vrele(((struct vnode *)(vp)))
+//#define VN_HOLD(vp)     VREF(((struct vnode *)(vp)))
 #define BIND_8_COMPAT
 
 #endif
@@ -91,6 +93,7 @@
 #define AFS_USR_DARWIN14_ENV
 #define AFS_USR_DARWIN60_ENV
 #define AFS_USR_DARWIN70_ENV
+#undef  AFS_NONFSTRANS
 #define AFS_NONFSTRANS
 #define AFS_SYSCALL             230
 #define DARWIN_REFBASE 0
