@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/kauth/kaprocs.c,v 1.17.8.2 2009/03/16 01:47:39 shadow Exp $");
 
 #include <afs/stds.h>
 #include <errno.h>
@@ -28,6 +26,8 @@ RCSID
 #include <lock.h>
 #include <ubik.h>
 #include <lwp.h>
+#include <des.h>
+#include <des_prototypes.h>
 #include <rx/xdr.h>
 #include <rx/rx.h>
 #include <rx/rxkad.h>
@@ -37,8 +37,6 @@ RCSID
 #include <netinet/in.h>
 #endif
 #include <string.h>
-#include <des.h>
-#include <des_prototypes.h>
 #include <afs/cellconfig.h>
 #include <afs/auth.h>
 #include <afs/com_err.h>
@@ -49,34 +47,15 @@ RCSID
 #include "kauth_internal.h"
 #include "afs/audit.h"
 
+#include "kadatabase.h"
+#include "kaprocs.h"
+
 extern struct ubik_dbase *KA_dbase;
 struct kaheader cheader;
 Date cheaderReadTime;		/* time cheader last read in */
 extern struct afsconf_dir *KA_conf;	/* for getting cell info */
 
-afs_int32 kamCreateUser(struct rx_call *call, char *aname, char *ainstance, 
-		        EncryptionKey ainitpw);
-afs_int32 ChangePassWord(struct rx_call *call, char *aname, char *ainstance, 
-		         ka_CBS *arequest, ka_BBS *oanswer);
-afs_int32 kamSetPassword(struct rx_call *call, char *aname, char *ainstance,
-	                 afs_int32 akvno, EncryptionKey apassword);
-afs_int32 kamSetFields(struct rx_call *call, char *aname, char *ainstance,
-		       afs_int32 aflags, Date aexpiration, 
-		       afs_int32 alifetime, afs_int32 amaxAssociates,
-		       afs_uint32 misc_auth_bytes, afs_int32 spare2);
-afs_int32 kamDeleteUser(struct rx_call *call, char *aname, char *ainstance);
-afs_int32 kamGetEntry(struct rx_call *call, char *aname, char *ainstance,
-		      afs_int32 aversion, kaentryinfo *aentry);
-afs_int32 kamListEntry(struct rx_call *call, afs_int32 previous_index,
-		       afs_int32 *index, afs_int32 *count, kaident *name);
-afs_int32 kamGetStats(struct rx_call *call, afs_int32 version, 
-		      afs_int32 *admin_accounts, kasstats *statics,
-		      kadstats *dynamics);
-afs_int32 kamGetPassword(struct rx_call *call, char *name, 
-		         EncryptionKey *password);
-afs_int32 kamGetRandomKey(struct rx_call *call, EncryptionKey *key);
-afs_int32 kamDebug(struct rx_call *call, afs_int32 version,
-		   int checkDB, struct ka_debugInfo *info);
+
 
 char lrealm[MAXKTCREALMLEN];
 
@@ -97,15 +76,13 @@ static afs_int32 autoCPWInterval;
 static afs_int32 autoCPWUpdates;
 
 static afs_int32 set_password(struct ubik_trans *tt, char *name, 
-			      char *instance, EncryptionKey *password, 
+			      char *instance,
+			      struct ktc_encryptionKey *password,
 			      afs_int32 kvno, afs_int32 caller);
-
-extern afs_int32 InitAuthServ(struct ubik_trans **tt, int lock,
-			      int *this_op);
 static afs_int32 impose_reuse_limits(EncryptionKey *password, 
 				     struct kaentry *tentry);
 static int create_user(struct ubik_trans *tt, char *name, char *instance,
-		       EncryptionKey *key, afs_int32 caller, 
+		       struct ktc_encryptionKey *key, afs_int32 caller,
 		       afs_int32 flags);
 
 /* This routine is called whenever an RPC interface needs the time.  It uses
@@ -172,12 +149,12 @@ get_time(Date *timeP,
 	if (to) {		/* check if auto cpw is disabled */
 	    if (!(ntohl(tentry.flags) & KAFNOCPW)) {
 		memcpy(&key, &random_value[0], sizeof(key));
-		des_fixup_key_parity(&key);
+		des_fixup_key_parity(ktc_to_cblock(&key));
 		code =
 		    set_password(tt, KA_ADMIN_NAME, KA_ADMIN_INST, &key, 0,
 				 0);
 		if (code == 0) {
-		    des_init_random_number_generator(&key);
+		    des_init_random_number_generator(ktc_to_cblock(&key));
 		    ka_ConvertBytes(buf, sizeof(buf), (char *)&key,
 				    sizeof(key));
 		    es_Report("New Admin key is %s\n", buf);
@@ -196,7 +173,7 @@ get_time(Date *timeP,
 	if (to) {		/* check if auto cpw is disabled */
 	    if (!(ntohl(tentry.flags) & KAFNOCPW)) {
 		memcpy(&key, &random_value[2], sizeof(key));
-		des_fixup_key_parity(&key);
+		des_fixup_key_parity(ktc_to_cblock(&key));
 		code = set_password(tt, KA_TGS_NAME, lrealm, &key, 0, 0);
 		if (code == 0) {
 		    ka_ConvertBytes(buf, sizeof(buf), (char *)&key,
@@ -243,14 +220,14 @@ initialize_database(struct ubik_trans *tt)
     int code;
 
     gettimeofday((struct timeval *)&key, 0);	/* this is just a cheap seed key */
-    des_fixup_key_parity(&key);
-    des_init_random_number_generator(&key);
-    if ((code = des_random_key(&key))
+    des_fixup_key_parity(ktc_to_cblock(&key));
+    des_init_random_number_generator(ktc_to_cblock(&key));
+    if ((code = des_random_key(ktc_to_cblock(&key)))
 	|| (code =
 	    create_user(tt, KA_ADMIN_NAME, KA_ADMIN_INST, &key, 0,
 			KAFNORMAL | KAFNOSEAL | KAFNOTGS)))
 	return code;
-    if ((code = des_random_key(&key))
+    if ((code = des_random_key(ktc_to_cblock(&key)))
 	|| (code =
 	    create_user(tt, KA_TGS_NAME, lrealm, &key, 0,
 			KAFNORMAL | KAFNOSEAL | KAFNOTGS)))
@@ -262,7 +239,7 @@ initialize_database(struct ubik_trans *tt)
    parameter passes some information about the command line arguments. */
 
 afs_int32
-init_kaprocs(char *lclpath, int initFlags)
+init_kaprocs(const char *lclpath, int initFlags)
 {
     int code;
     struct ubik_trans *tt;
@@ -314,7 +291,7 @@ init_kaprocs(char *lclpath, int initFlags)
 	     code);
 	return code;
     }
-    des_init_random_number_generator(&key);
+    des_init_random_number_generator(ktc_to_cblock(&key));
 
     code = ubik_EndTrans(tt);
     if (code) {
@@ -322,7 +299,7 @@ init_kaprocs(char *lclpath, int initFlags)
 	return code;
     }
 
-    kaux_opendb(lclpath);	/* aux database stores failure counters */
+    kaux_opendb((char *)lclpath);/* aux database stores failure counters */
     rebuildDatabase = 0;	/* only do this during init */
     kaprocsInited = 1;
     return 0;
@@ -573,7 +550,8 @@ special_name(char *name, char *instance)
 
 static int
 create_user(struct ubik_trans *tt, char *name, char *instance,
-	    EncryptionKey *key, afs_int32 caller, afs_int32 flags)
+	    struct ktc_encryptionKey *key, afs_int32 caller,
+	    afs_int32 flags)
 {
     register int code;
     afs_int32 to;
@@ -651,7 +629,7 @@ kamCreateUser(struct rx_call *call, char *aname, char *ainstance,
     afs_int32 caller;		/* Disk offset of caller's entry */
 
     COUNT_REQ(CreateUser);
-    if (!des_check_key_parity(&ainitpw) || des_is_weak_key(&ainitpw))
+    if (!des_check_key_parity(EncryptionKey_to_cblock(&ainitpw)) || des_is_weak_key(EncryptionKey_to_cblock(&ainitpw)))
 	return KABADKEY;
     if (!name_instance_legal(aname, ainstance))
 	return KABADNAME;
@@ -663,7 +641,7 @@ kamCreateUser(struct rx_call *call, char *aname, char *ainstance,
 	ubik_AbortTrans(tt);
 	return code;
     }
-    code = create_user(tt, aname, ainstance, &ainitpw, caller, KAFNORMAL);
+    code = create_user(tt, aname, ainstance, EncryptionKey_to_ktc(&ainitpw), caller, KAFNORMAL);
     if (code) {
 	COUNT_ABO;
 	ubik_AbortTrans(tt);
@@ -724,11 +702,11 @@ ChangePassWord(struct rx_call *call, char *aname, char *ainstance,
     }
 
     /* decrypt request w/ user password */
-    if ((code = des_key_sched(&tentry.key, user_schedule)))
+    if ((code = des_key_sched(ktc_to_cblock(&tentry.key), user_schedule)))
 	es_Report("In KAChangePassword: key_sched returned %d\n", code);
     des_pcbc_encrypt(arequest->SeqBody, &request,
 		     min(arequest->SeqLen, sizeof(request)), user_schedule,
-		     &tentry.key, DECRYPT);
+		     ktc_to_cblockptr(&tentry.key), DECRYPT);
 
     /* validate the request */
     request_time = ntohl(request.time);	/* reorder date */
@@ -741,7 +719,7 @@ ChangePassWord(struct rx_call *call, char *aname, char *ainstance,
     /* check to see if the new password was used before, or if there has
      * not been sufficient time since the last password change
      */
-    code = impose_reuse_limits(&request.newpw, &tentry);
+    code = impose_reuse_limits(ktc_to_EncryptionKey(&request.newpw), &tentry);
     if (code) {
 	goto abort;
     }
@@ -760,7 +738,7 @@ ChangePassWord(struct rx_call *call, char *aname, char *ainstance,
     memcpy(answer, KA_CPW_ANS_LABEL, KA_LABELSIZE);
 
     des_pcbc_encrypt(oanswer->SeqBody, oanswer->SeqBody, answer_len,
-		     user_schedule, &tentry.key, ENCRYPT);
+		     user_schedule, ktc_to_cblockptr(&tentry.key), ENCRYPT);
 
     code = set_password(tt, aname, ainstance, &request.newpw, kvno, 0);
     if (code) {
@@ -824,7 +802,7 @@ impose_reuse_limits(EncryptionKey *password, struct kaentry *tentry)
 
 static afs_int32
 set_password(struct ubik_trans *tt, char *name, char *instance, 
-	     EncryptionKey *password, afs_int32 kvno, afs_int32 caller)
+	     struct ktc_encryptionKey *password, afs_int32 kvno, afs_int32 caller)
 {
     afs_int32 code;
     afs_int32 to;		/* offset of block */
@@ -882,7 +860,7 @@ set_password(struct ubik_trans *tt, char *name, char *instance,
 
     tentry.change_password_time = htonl(now);
 
-    if (code = kawrite(tt, to, &tentry, sizeof(tentry)))
+    if ((code = kawrite(tt, to, (char *) &tentry, sizeof(tentry))))
 	return (KAIO);
     return (0);
 }
@@ -911,7 +889,7 @@ kamSetPassword(struct rx_call *call, char *aname, char *ainstance,
     COUNT_REQ(SetPassword);
     if (akvno > MAXKAKVNO)
 	return KABADARGUMENT;
-    if (!des_check_key_parity(&apassword) || des_is_weak_key(&apassword))
+    if (!des_check_key_parity(EncryptionKey_to_cblock(&apassword)) || des_is_weak_key(EncryptionKey_to_cblock(&apassword)))
 	return KABADKEY;
 
     if (!name_instance_legal(aname, ainstance))
@@ -922,7 +900,7 @@ kamSetPassword(struct rx_call *call, char *aname, char *ainstance,
     if (code) {
 	goto abort;
     }
-    if ((code = karead(tt, caller, &tentry, sizeof(tentry)))) {
+    if ((code = karead(tt, caller, (char *)&tentry, sizeof(tentry)))) {
 	code = KAIO;
 	goto abort;
     }
@@ -935,10 +913,10 @@ kamSetPassword(struct rx_call *call, char *aname, char *ainstance,
 	    code = impose_reuse_limits(&apassword, &tentry);
 	    if (!code)
 		code =
-		    set_password(tt, aname, ainstance, &apassword, akvno, 0);
+		    set_password(tt, aname, ainstance, EncryptionKey_to_ktc(&apassword), akvno, 0);
 	}
     } else if (ntohl(tentry.flags) & KAFADMIN) {
-	code = set_password(tt, aname, ainstance, &apassword, akvno, caller);
+	code = set_password(tt, aname, ainstance, EncryptionKey_to_ktc(&apassword), akvno, caller);
     } else
 	code = KANOAUTH;
     if (code)
@@ -1122,11 +1100,11 @@ Authenticate(int version, struct rx_call *call, char *aname, char *ainstance,
     save_principal(authPrincipal, aname, ainstance, 0);
 
     /* decrypt request w/ user password */
-    if ((code = des_key_sched(&tentry.key, user_schedule)))
+    if ((code = des_key_sched(ktc_to_cblock(&tentry.key), user_schedule)))
 	es_Report("In KAAuthenticate: key_sched returned %d\n", code);
     des_pcbc_encrypt(arequest->SeqBody, &request,
 		     min(arequest->SeqLen, sizeof(request)), user_schedule,
-		     &tentry.key, DECRYPT);
+		     ktc_to_cblockptr(&tentry.key), DECRYPT);
 
     request.time = ntohl(request.time);	/* reorder date */
     tgt = !strncmp(request.label, KA_GETTGT_REQ_LABEL, sizeof(request.label));
@@ -1188,7 +1166,7 @@ Authenticate(int version, struct rx_call *call, char *aname, char *ainstance,
     tgskvno = ntohl(server.key_version);
     memcpy(&tgskey, &server.key, sizeof(tgskey));
 
-    code = des_random_key(&sessionKey);
+    code = des_random_key(ktc_to_cblock(&sessionKey));
     if (code) {
 	code = KANOKEYS;
 	goto abort;
@@ -1266,7 +1244,7 @@ Authenticate(int version, struct rx_call *call, char *aname, char *ainstance,
 	goto abort;
     }
     des_pcbc_encrypt(oanswer->SeqBody, oanswer->SeqBody, oanswer->SeqLen,
-		     user_schedule, &tentry.key, ENCRYPT);
+		     user_schedule, ktc_to_cblockptr(&tentry.key), ENCRYPT);
     code = ubik_EndTrans(tt);
     KALOG(aname, ainstance, sname, sinst, NULL, call->conn->peer->host,
 	  LOG_AUTHENTICATE);
@@ -1472,7 +1450,7 @@ kamSetFields(struct rx_call *call,
 
     tentry.modification_time = htonl(now);
     tentry.modification_id = htonl(caller);
-    code = kawrite(tt, tentry_offset, &tentry, sizeof(tentry));
+    code = kawrite(tt, tentry_offset, (char *) &tentry, sizeof(tentry));
     if (code)
 	goto abort;
 
@@ -1610,7 +1588,7 @@ kamGetEntry(struct rx_call *call,
 	code = KANOENT;
 	goto abort;
     } else {
-	if ((code = karead(tt, callerIndex, &caller, sizeof(caller)))) {
+	if ((code = karead(tt, callerIndex, (char *)&caller, sizeof(caller)))) {
 	    code = KAIO;
 	    goto abort;
 	}
@@ -1669,7 +1647,7 @@ kamGetEntry(struct rx_call *call,
     /* Now get entry of user who last modified this entry */
     if (ntohl(tentry.modification_id)) {
 	temp = ntohl(tentry.modification_id);
-	code = karead(tt, temp, &tentry, sizeof(tentry));
+	code = karead(tt, temp, (char *)&tentry, sizeof(tentry));
 	if (code) {
 	    code = KAIO;
 	    goto abort;
@@ -1822,7 +1800,7 @@ GetTicket(int version,
 	    code = KANOAUTH;
 	goto abort;
     }
-    code = des_key_sched(&authSessionKey, schedule);
+    code = des_key_sched(ktc_to_cblock(&authSessionKey), schedule);
     if (code) {
 	code = KANOAUTH;
 	goto abort;
@@ -1877,7 +1855,7 @@ GetTicket(int version,
     }
     save_principal(tgsServerPrincipal, sname, sinstance, 0);
 
-    code = des_random_key(&sessionKey);
+    code = des_random_key(ktc_to_cblock(&sessionKey));
     if (code) {
 	code = KANOKEYS;
 	goto abort;
@@ -1951,7 +1929,7 @@ GetTicket(int version,
 	goto abort;
     }
     des_pcbc_encrypt(oanswer->SeqBody, oanswer->SeqBody, oanswer->SeqLen,
-		     schedule, &authSessionKey, ENCRYPT);
+		     schedule, ktc_to_cblockptr(&authSessionKey), ENCRYPT);
     code = ubik_EndTrans(tt);
     KALOG(name, instance, sname, sinstance, (import ? authDomain : NULL),
 	  call->conn->peer->host, LOG_GETTICKET);
@@ -2167,7 +2145,7 @@ kamGetRandomKey(struct rx_call *call, EncryptionKey *key)
     COUNT_REQ(GetRandomKey);
     if ((code = AwaitInitialization()))
 	return code;
-    code = des_random_key(key);
+    code = des_random_key(EncryptionKey_to_cblock(key));
     if (code)
 	return KANOKEYS;
     return 0;
@@ -2326,7 +2304,7 @@ SKAM_LockStatus(struct rx_call *call,
 	goto abort;
 
     if (!noAuthenticationRequired && callerIndex) {
-	if (karead(tt, callerIndex, &caller, sizeof(caller))) {
+	if (karead(tt, callerIndex, (char *)&caller, sizeof(caller))) {
 	    code = KAIO;
 	    goto abort;
 	}
