@@ -15,8 +15,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/kauth/kkids.c,v 1.7 2005/11/05 06:48:11 jaltman Exp $");
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -26,6 +24,7 @@ RCSID
 #include <winsock2.h>
 #include <afs/fs_utils.h>
 #else
+#include <unistd.h>
 #include <netinet/in.h>
 #include <afs/venus.h>
 #endif
@@ -35,6 +34,9 @@ RCSID
 #include <afs/prs_fs.h>
 #include <stdlib.h>
 #include <string.h>
+#include <afs/sys_prototypes.h>
+
+#include "kkids.h"
 
 #define MAXNAME 100
 #define MAXSIZE 2048
@@ -302,7 +304,6 @@ is_secure(char *dir)
     struct ViceIoctl blob;
     struct AclEntry *te;
     char space[2046];
-    int secure = 1;
     afs_int32 code;
     struct Acl *ta;
 
@@ -422,6 +423,7 @@ init_child(char *myname)
 	argv[1] = NULL;
 	argv[0] = dirpath;
 	execv(dirpath, argv);
+	return 0;
     } else {
 	using_child = pid;	/* save it for later */
 	childin = fdopen(pipe1[1], "w");
@@ -466,7 +468,7 @@ give_to_child(char *pw)
 /* quickly and painlessly
  */
 int
-terminate_child(char *pw)
+terminate_child(void)
 {
     int rc;
     rc = 0;
