@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/libadmin/client/afs_clientAdmin.c,v 1.11.4.3 2008/02/29 01:27:57 jaltman Exp $");
 
 #include <afs/stds.h>
 #include "afs_clientAdmin.h"
@@ -38,6 +36,7 @@ RCSID
 #include <string.h>
 #include <afs/kautils.h>
 #include <rx/rx.h>
+#include <rx/rxstat.h>
 #include <rx/rx_null.h>
 #include <rx/rxkad.h>
 #include <afs/dirpath.h>
@@ -47,6 +46,7 @@ RCSID
 #include <afs/ptserver.h>
 #include <afs/vlserver.h>
 #include <afs/pthread_glock.h>
+#include <afs/sys_prototypes.h>
 
 /*
  * AFS client administration functions.
@@ -1367,7 +1367,8 @@ afsclient_MountPointCreate(const void *cellHandle, const char *directory,
      */
 
     if (volCheck == CHECK_VOLUME) {
-	if (!vos_VLDBGet(cellHandle, 0, 0, volumeName, &vldbEntry, &tst)) {
+	if (!vos_VLDBGet(cellHandle, 0, 0, (char *)volumeName, &vldbEntry,
+		         &tst)) {
 	    goto fail_afsclient_MountPointCreate;
 	}
     }
@@ -1499,7 +1500,7 @@ afsclient_ACLEntryAdd(const char *directory, const char *user,
     idata.out_size = 2048;
     idata.in_size = 0;
     idata.in = idata.out = old_acl_string;
-    tst = pioctl(directory, VIOCGETAL, &idata, 1);
+    tst = pioctl((char *)directory, VIOCGETAL, &idata, 1);
 
     if (tst != 0) {
 	goto fail_afsclient_ACLEntryAdd;
@@ -1588,7 +1589,7 @@ afsclient_ACLEntryAdd(const char *directory, const char *user,
     idata.out_size = 0;
     idata.in_size = strlen(new_acl_string) + 1;
     idata.in = idata.out = new_acl_string;
-    tst = pioctl(directory, VIOCSETAL, &idata, 1);
+    tst = pioctl((char *) directory, VIOCSETAL, &idata, 1);
 
     if (tst != 0) {
 	goto fail_afsclient_ACLEntryAdd;
@@ -1835,7 +1836,7 @@ afsclient_AFSServerGetBegin(const void *cellHandle, void **iterationIdP,
 	(afs_admin_iterator_p) malloc(sizeof(afs_admin_iterator_t));
     server_get_p serv = (server_get_p) calloc(1, sizeof(server_get_t));
     server_get_p serv_cache = NULL;
-    const char *cellName;
+    const char *cellName = NULL;
     void *database_iter;
     util_databaseServerEntry_t database_entry;
     void *fileserver_iter;
