@@ -18,10 +18,9 @@
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <afs/afsutil.h>
+#include <unistd.h>
 #endif
 
-RCSID
-    ("$Header: /cvs/openafs/src/libadmin/test/vos.c,v 1.9.4.3 2008/10/27 23:41:46 shadow Exp $");
 
 #include "vos.h"
 
@@ -72,7 +71,7 @@ GetVolumeIdFromString(const char *volume)
      * is a volume name
      */
     if (vos_VLDBGet
-	(cellHandle, 0, (const unsigned int *)0, volume, &entry, &st)) {
+	(cellHandle, 0, NULL, (char *)volume, &entry, &st)) {
 	return entry.volumeId[VOS_READ_WRITE_VOLUME];
     } else {
 	ERR_EXT("failed to convert specified volume to an id");
@@ -140,11 +139,13 @@ GetAddressFromString(const char *addr_str)
     return ntohl(addr);
 }
 
+#if 0
 static void
 PrintMessage(vos_messageType_t type, char *message)
 {
     printf("%s\n", message);
 }
+#endif
 
 int
 DoVosBackupVolumeCreate(struct cmd_syndesc *as, void *arock)
@@ -532,7 +533,7 @@ DoVosVLDBGet(struct cmd_syndesc *as, void *arock)
     afs_status_t st = 0;
     vos_vldbEntry_t entry;
     unsigned int volume_id;
-    const char *volume_name = NULL;
+    char *volume_name = NULL;
 
     if (as->parms[VOLUME].items) {
 	const char *volume = as->parms[VOLUME].items->data;
@@ -832,7 +833,7 @@ DoVosVolumeCreate(struct cmd_syndesc *as, void *arock)
     void *vos_server = NULL;
     unsigned int partition_id = 0;
     unsigned int volume_id;
-    const char *volume = NULL;
+    char *volume = NULL;
     unsigned int quota = 0;
 
     if (as->parms[SERVER].items) {
@@ -907,7 +908,7 @@ DoVosVolumeRename(struct cmd_syndesc *as, void *arock)
     typedef enum { OLDVOLUME, NEWVOLUME } DoVosVolumeRename_parm_t;
     afs_status_t st = 0;
     unsigned int old_volume = 0;
-    const char *new_volume = 0;
+    char *new_volume = NULL;
 
     if (as->parms[OLDVOLUME].items) {
 	const char *volume = as->parms[OLDVOLUME].items->data;
@@ -993,7 +994,7 @@ DoVosVolumeRestore(struct cmd_syndesc *as, void *arock)
     unsigned int volume_id;
     unsigned int *vol_ptr = NULL;
     const char *dumpfile = NULL;
-    const char *volume_name = NULL;
+    char *volume_name = NULL;
     vos_volumeRestoreType_t restore = VOS_RESTORE_INCREMENTAL;
 
     if (as->parms[SERVER].items) {
@@ -1541,7 +1542,6 @@ int
 DoVosPartitionNameToId(struct cmd_syndesc *as, void *arock)
 {
     typedef enum { PARTITION } DoVosPartitionNameToId_parm_t;
-    afs_status_t st = 0;
     unsigned int partition_id = 0;
 
     if (as->parms[PARTITION].items) {
@@ -1675,7 +1675,7 @@ Print_vos_volintInfo(afs_uint32 server, afs_uint32 partition, volintInfo* pinfo,
     
     
     printf("%sname\t\t%s\n",prefix, pinfo->name);
-    printf("%sid\t\t%lu\n",prefix, pinfo->volid);
+    printf("%sid\t\t%lu\n",prefix, afs_printable_uint32_lu(pinfo->volid));
     printf("%sserv\t\t%s\t%s\n",prefix, address,hostname);
     printf("%spart\t\t%u\n", prefix,partition);
     
@@ -1690,9 +1690,12 @@ Print_vos_volintInfo(afs_uint32 server, afs_uint32 partition, volintInfo* pinfo,
 	printf("%sstatus\t\tUNATTACHABLE\n",prefix);
 	return;
     }
-    printf("%sbackupID\t%lu\n",prefix, pinfo->backupID);
-    printf("%sparentID\t%lu\n",prefix, pinfo->parentID);
-    printf("%scloneID\t%lu\n",prefix, pinfo->cloneID);
+    printf("%sbackupID\t%lu\n",prefix,
+	   afs_printable_uint32_lu(pinfo->backupID));
+    printf("%sparentID\t%lu\n",prefix,
+	   afs_printable_uint32_lu(pinfo->parentID));
+    printf("%scloneID\t%lu\n",prefix,
+	   afs_printable_uint32_lu(pinfo->cloneID));
     printf("%sinUse\t\t%s\n",prefix, pinfo->inUse ? "Y" : "N");
     printf("%sneedsSalvaged\t%s\n",prefix, pinfo->needsSalvaged ? "Y" : "N");
     /* 0xD3 is from afs/volume.h since I had trouble including the file */
@@ -1711,21 +1714,30 @@ Print_vos_volintInfo(afs_uint32 server, afs_uint32 partition, volintInfo* pinfo,
 	printf("%stype\t\t?\n",prefix);
 	break;
     }
-    printf("%screationDate\t%-9lu\n", prefix,pinfo->creationDate);
-    printf("%saccessDate\t%-9lu\n", prefix,pinfo->accessDate);
-    printf("%supdateDate\t%-9lu\n", prefix,pinfo->updateDate);
-    printf("%sbackupDate\t%-9lu\n", prefix,pinfo->backupDate);
-    printf("%scopyDate\t%-9lu\n", prefix,pinfo->copyDate);
+    printf("%screationDate\t%-9lu\n", prefix,
+	   afs_printable_uint32_lu(pinfo->creationDate));
+    printf("%saccessDate\t%-9lu\n", prefix,
+	   afs_printable_uint32_lu(pinfo->accessDate));
+    printf("%supdateDate\t%-9lu\n", prefix,
+	   afs_printable_uint32_lu(pinfo->updateDate));
+    printf("%sbackupDate\t%-9lu\n", prefix,
+	   afs_printable_uint32_lu(pinfo->backupDate));
+    printf("%scopyDate\t%-9lu\n", prefix,
+	   afs_printable_uint32_lu(pinfo->copyDate));
 	    
-    printf("%sflags\t\t%#lx\t(Optional)\n",prefix, pinfo->flags);
+    printf("%sflags\t\t%#lx\t(Optional)\n",prefix, afs_printable_int32_ld(pinfo->flags));
     printf("%sdiskused\t%u\n",prefix, pinfo->size);
     printf("%smaxquota\t%u\n",prefix, pinfo->maxquota);
-    printf("%sminquota\t%lu\t(Optional)\n",prefix, pinfo->spare0);
+    printf("%sminquota\t%lu\t(Optional)\n",prefix,
+	   afs_printable_uint32_lu(pinfo->spare0));
     printf("%sfilecount\t%u\n",prefix, pinfo->filecount);
     printf("%sdayUse\t\t%u\n",prefix, pinfo->dayUse);
-    printf("%sweekUse\t%lu\t(Optional)\n",prefix, pinfo->spare1);
-    printf("%svolUpdateCounter\t\t%lu\t(Optional)\n",prefix, pinfo->spare2);
-    printf("%sspare3\t\t%lu\t(Optional)\n",prefix, pinfo->spare3);
+    printf("%sweekUse\t%lu\t(Optional)\n",prefix,
+	   afs_printable_uint32_lu(pinfo->spare1));
+    printf("%svolUpdateCounter\t\t%lu\t(Optional)\n",prefix,
+           afs_printable_uint32_lu(pinfo->spare2));
+    printf("%sspare3\t\t%lu\t(Optional)\n",prefix,
+	   afs_printable_uint32_lu(pinfo->spare3));
 }
 
 int
