@@ -17,10 +17,12 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/lwp/lwp.c,v 1.34.2.6 2008/03/13 13:42:19 shadow Exp $");
 
 #include <stdlib.h>
 #include <stdio.h>
+#ifdef HAVE_STDINT_H
+#include <stdint.h>
+#endif
 #include <time.h>
 
 /* allocate externs here */
@@ -932,9 +934,9 @@ Dispatcher(void)
 #endif
 	printf("stackcheck = %u: stack = %u \n", lwp_cpptr->stackcheck,
 	       *(int *)lwp_cpptr->stack);
-	printf("topstack = 0x%x: stackptr = 0x%x: stacksize = 0x%x\n",
-	       (unsigned int)lwp_cpptr->context.topstack, 
-	       (unsigned int)lwp_cpptr->stack,
+	printf("topstack = 0x%" AFS_PTR_FMT ": stackptr = 0x%" AFS_PTR_FMT ": stacksize = 0x%x\n",
+	       (void *)(uintptr_t)lwp_cpptr->context.topstack,
+	       (void *)(uintptr_t)lwp_cpptr->stack,
 	       lwp_cpptr->stacksize);
 
 	switch (lwp_overflowAction) {
