@@ -119,10 +119,10 @@ xdr_u_int(XDR * xdrs, u_int * uip)
 
     case XDR_ENCODE:
 	l = (afs_uint32) * uip;
-	return (XDR_PUTINT32(xdrs, &l));
+	return (XDR_PUTINT32(xdrs, (afs_int32 *) &l));
 
     case XDR_DECODE:
-	if (!XDR_GETINT32(xdrs, &l)) {
+	if (!XDR_GETINT32(xdrs, (afs_int32 *) &l)) {
 	    return (FALSE);
 	}
 	*uip = (u_int) l;
@@ -174,10 +174,10 @@ xdr_u_long(XDR * xdrs, u_long * ulp)
 
     case XDR_ENCODE:
 	l = (afs_uint32) * ulp;
-	return (XDR_PUTINT32(xdrs, &l));
+	return (XDR_PUTINT32(xdrs, (afs_int32 *)&l));
 
     case XDR_DECODE:
-	if (!XDR_GETINT32(xdrs, &l)) {
+	if (!XDR_GETINT32(xdrs, (afs_int32 *)&l)) {
 	    return (FALSE);
 	}
 	*ulp = (u_long) l;
@@ -229,10 +229,10 @@ xdr_u_char(XDR * xdrs, u_char * usp)
 
     case XDR_ENCODE:
 	l = (afs_uint32) * usp;
-	return (XDR_PUTINT32(xdrs, &l));
+	return (XDR_PUTINT32(xdrs, (afs_int32 *)&l));
 
     case XDR_DECODE:
-	if (!XDR_GETINT32(xdrs, &l)) {
+	if (!XDR_GETINT32(xdrs, (afs_int32 *)&l)) {
 	    return (FALSE);
 	}
 	*usp = (u_char) l;
@@ -284,10 +284,10 @@ xdr_u_short(XDR * xdrs, u_short * usp)
 
     case XDR_ENCODE:
 	l = (afs_uint32) * usp;
-	return (XDR_PUTINT32(xdrs, &l));
+	return (XDR_PUTINT32(xdrs, (afs_int32 *)&l));
 
     case XDR_DECODE:
-	if (!XDR_GETINT32(xdrs, &l)) {
+	if (!XDR_GETINT32(xdrs, (afs_int32 *)&l)) {
 	    return (FALSE);
 	}
 	*usp = (u_short) l;
