@@ -36,8 +36,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/rxgen/rpc_main.c,v 1.23.4.7 2008/12/21 06:05:33 jaltman Exp $");
 
 #include <limits.h>
 #include <stdio.h>
@@ -531,6 +529,8 @@ h_output(char *infile, char *define, int extend, char *outfile, int append)
     while ((def = get_definition())) {
 	print_datadef(def);
     }
+    printf("Printing ex_req\n");
+    h_Proc_CodeGeneration();
     h_opcode_stats();
     hflag = 0;
     f_print(fout, "#endif	/* _RXGEN_%s_ */\n", uppercase(fullname));
