@@ -35,19 +35,11 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/rxgen/rpc_parse.c,v 1.20.4.2 2006/07/04 06:28:26 jaltman Exp $");
 
 #include <stdlib.h>
 #include <stdio.h>
 #include <ctype.h>
-#ifdef HAVE_STRING_H
 #include <string.h>
-#else
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
-#endif
 #include "rpc_scan.h"
 #include "rpc_parse.h"
 #include "rpc_util.h"
@@ -939,7 +931,7 @@ static void
 handle_split_proc(definition * defp, int multi_flag)
 {
     char *startname = SplitStart, *endname = SplitEnd;
-    int numofparams;
+    int numofparams = 0;
 
     if (!startname)
 	startname = "Start";
@@ -1116,20 +1108,29 @@ cs_Proc_CodeGeneration(definition * defp, int split_flag, char *procheader)
     }
 }
 
-
 static void
 cs_ProcName_setup(definition * defp, char *procheader, int split_flag)
 {
     proc1_list *plist;
+    char *first_arg;
+
+    if (ansic_flag) {
+	if (split_flag) {
+	    first_arg = "register struct rx_call *z_call";
+	} else {
+	    first_arg = "register struct rx_connection *z_conn";
+	}
+    } else {
+	if (split_flag) {
+	    first_arg = "z_call";
+	} else {
+	    first_arg = "z_conn";
+	}
+    }
 
     if (!cflag) {
-	if (split_flag) {
-	    f_print(fout, "int %s%s%s%s(z_call", procheader, prefix,
-		    PackagePrefix[PackageIndex], defp->pc.proc_name);
-	} else {
-	    f_print(fout, "int %s%s%s%s(z_conn", procheader, prefix,
-		    PackagePrefix[PackageIndex], defp->pc.proc_name);
-	}
+	f_print(fout, "int %s%s%s%s(%s", procheader, prefix,
+		PackagePrefix[PackageIndex], defp->pc.proc_name, first_arg);
     }
     if ((strlen(procheader) + strlen(prefix) +
 	 strlen(PackagePrefix[PackageIndex]) + strlen(defp->pc.proc_name)) >=
@@ -1139,20 +1140,32 @@ cs_ProcName_setup(definition * defp, char *procheader, int split_flag)
     if (!cflag) {
 	for (plist = defp->pc.plists; plist; plist = plist->next) {
 	    if (plist->component_kind == DEF_PARAM) {
-		plist->pl.param_flag &= ~PROCESSED_PARAM;
-		f_print(fout, ", %s", plist->pl.param_name);
+		if (ansic_flag) {
+		    if (plist->pl.param_flag & OUT_STRING) {
+			f_print(fout, ",%s *%s", plist->pl.param_type,
+				plist->pl.param_name);
+		    } else {
+			f_print(fout, ",%s %s", plist->pl.param_type,
+				plist->pl.param_name);
+		    }
+		} else {
+		    f_print(fout, ", %s", plist->pl.param_name);    
+		    plist->pl.param_flag &= ~PROCESSED_PARAM;
+		}
 	    }
 	}
 	f_print(fout, ")\n");
     }
 }
 
-
 static void
 cs_ProcParams_setup(definition * defp, int split_flag)
 {
     proc1_list *plist, *plist1;
 
+    if (ansic_flag)
+	return;
+
     if (!split_flag)
 	f_print(fout, "\tregister struct rx_connection *z_conn;\n");
     if (split_flag) {
@@ -1454,6 +1467,7 @@ ss_ProcParams_setup(definition * defp, int *somefrees)
 		    switch (defp1->pc.rel) {
 		    case REL_ARRAY:
 		    case REL_POINTER:
+		    default:
 			break;
 		    }
 		}
@@ -1513,6 +1527,8 @@ ss_ProcSpecial_setup(definition * defp, int *somefrees)
 			f_print(fout, "\n\t%s = 0;", plist->pl.param_name);
 			plist->pl.string_name = NULL;
 			break;
+		    default:
+			break;
 		    }
 		}
 	    }
@@ -1662,6 +1678,8 @@ ss_ProcTail_setup(definition * defp, int somefrees)
 			f_print(fout, "\tif (!%s) goto fail1;\n",
 				plist->scode);
 			break;
+		    default:
+			break;
 		    }
 		}
 	    }
@@ -1748,8 +1766,14 @@ ucs_ProcName_setup(definition * defp, char *procheader, int split_flag)
     proc1_list *plist;
 
     if (!cflag) {
-      f_print(fout, "int %s%s%s%s(aclient, aflags", procheader, prefix,
-	      PackagePrefix[PackageIndex], defp->pc.proc_name);
+     	if (ansic_flag) {
+	    f_print(fout, "int %s%s%s%s(register struct ubik_client *aclient, afs_int32 aflags",
+			  procheader, prefix, PackagePrefix[PackageIndex],
+			  defp->pc.proc_name);
+	} else {
+	    f_print(fout, "int %s%s%s%s(aclient, aflags", procheader, prefix,
+			  PackagePrefix[PackageIndex], defp->pc.proc_name);
+	}
     }
     if ((strlen(procheader) + strlen(prefix) +
 	 strlen(PackagePrefix[PackageIndex]) + strlen(defp->pc.proc_name)) >=
@@ -1759,8 +1783,18 @@ ucs_ProcName_setup(definition * defp, char *procheader, int split_flag)
     if (!cflag) {
 	for (plist = defp->pc.plists; plist; plist = plist->next) {
 	    if (plist->component_kind == DEF_PARAM) {
-		plist->pl.param_flag &= ~PROCESSED_PARAM;
-		f_print(fout, ", %s", plist->pl.param_name);
+		if (ansic_flag) {
+		    if (plist->pl.param_flag & OUT_STRING) {
+			f_print(fout, ",%s *%s", plist->pl.param_type,
+				plist->pl.param_name);
+		    } else {
+			f_print(fout, ",%s %s", plist->pl.param_type,
+				plist->pl.param_name);
+		    }
+		} else {
+		    plist->pl.param_flag &= ~PROCESSED_PARAM;
+		    f_print(fout, ", %s", plist->pl.param_name);
+		}
 	    }
 	}
 	f_print(fout, ")\n");
@@ -1773,6 +1807,9 @@ ucs_ProcParams_setup(definition * defp, int split_flag)
 {
     proc1_list *plist, *plist1;
 
+    if (ansic_flag)
+	return;
+
     f_print(fout, "\tregister struct ubik_client *aclient;\n\tafs_int32 aflags;\n");
     for (plist = defp->pc.plists; plist; plist = plist->next) {
 	if (plist->component_kind == DEF_PARAM
@@ -2117,6 +2154,38 @@ er_TailofOldStyleProc_setup(void)
     f_print(fout, "\treturn z_result;\n}\n");
 }
 
+static void
+h_ProcMainBody_setup(void)
+{
+    f_print(fout,"\nextern int %s%sExecuteRequest(struct rx_call *);\n",
+	    prefix, PackagePrefix[PackageIndex]);
+}
+
+static void
+h_HeadofOldStyleProc_setup(void)
+{
+    f_print(fout,"\nextern int %s%sExecuteRequest(struct rx_call *);\n",
+	    prefix,
+	    (combinepackages ? MasterPrefix : PackagePrefix[PackageIndex]));
+}
+
+void
+h_Proc_CodeGeneration(void)
+{
+    int temp;
+
+    temp = PackageIndex;
+    if (!combinepackages)
+        PackageIndex = 0;
+    for (; PackageIndex <= temp; PackageIndex++) {
+	if (combinepackages || opcode_holes_exist()) {
+	    h_HeadofOldStyleProc_setup();
+	} else {
+            h_ProcMainBody_setup();
+	}
+    }
+    PackageIndex = temp;
+}
 
 void
 h_opcode_stats(void)
