@@ -19,8 +19,6 @@
 #include <afs/param.h>
 #endif
 
-RCSID
-    ("$Header: /cvs/openafs/src/rxkad/domestic/fcrypt.c,v 1.18.2.3 2009/03/18 13:41:39 shadow Exp $");
 
 #define DEBUG 0
 #ifdef KERNEL
@@ -41,8 +39,6 @@ RCSID
 #include <asm/byteorder.h>
 #endif
 
-#include "afs/longc_procs.h"
-
 #else /* KERNEL */
 
 #include <afs/stds.h>
