@@ -14,8 +14,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/rxkad/rxkad_server.c,v 1.21.2.6 2008/11/29 18:08:49 shadow Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -472,7 +470,7 @@ afs_int32 rxkad_SetConfiguration(struct rx_securityClass *aobj,
         if (currentValue) {
             *((afs_uint32 *)currentValue) = private->flags;
         } else { 
-            private->flags = (afs_uint32) avalue;
+            private->flags = (intptr_t)avalue;
         }
         break;
     default:
