@@ -17,8 +17,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/tviced/state_analyzer.c,v 1.1 2006/03/23 15:09:13 shadow Exp $");
 
 #include <stdio.h>
 #include <errno.h>
@@ -26,14 +24,7 @@ RCSID
 #include <netdb.h>
 #include <netinet/in.h>
 #include <time.h>
-
-#ifdef HAVE_STRING_H
 #include <string.h>
-#else
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
-#endif
 
 #include <afs/stds.h>
 #include <rx/xdr.h>
@@ -53,7 +44,6 @@ RCSID
 #include <afs/acl.h>
 #include <afs/ptclient.h>
 #include <afs/prs_fs.h>
-#include <afs/auth.h>
 #include <afs/afsutil.h>
 #include <rx/rx.h>
 #include <afs/cellconfig.h>
@@ -247,21 +237,16 @@ static struct {
     byte cb_valid;
 } cb_cursor;
 
-static struct {
-    void ** cursor;
-} cb_cache;
-
 static void
 usage(char * prog)
 {
-    fprintf(stderr, "usage: %s [<state dump file>]\n");
+    fprintf(stderr, "usage: %s [<state dump file>]\n", prog);
 }
 
 int
 main(int argc, char ** argv)
 {
     banner();
-
     if (argc > 2 || (argc == 2 && !strcmp(argv[1], "-h"))) {
 	usage(argv[0]);
 	return 1;
@@ -273,7 +258,7 @@ main(int argc, char ** argv)
 	if (openFile(argv[1]))
 	    return 1;
     } else {
-	if (openFile(AFSDIR_SERVER_FSSTATE_FILEPATH))
+	if (openFile((char *)AFSDIR_SERVER_FSSTATE_FILEPATH))
 	    return 1;
     }
 
@@ -312,7 +297,7 @@ openFile(char * path)
 	goto done;
     }
 
-    printf("mapped %d bytes at 0x%x\n", map_len, map);
+    printf("mapped %lu bytes at %"AFS_PTR_FMT"\n", (unsigned long)map_len, map);
 
  done:
     if (ret) {
@@ -752,7 +737,7 @@ print_cb_help(void)
     do { \
         char * _p = (char *)addr; \
         char * _m = (char *)map; \
-        printf("loading structure from address 0x%x (offset %u)\n", \
+        printf("loading structure from address %"AFS_PTR_FMT" (offset %u)\n", \
                addr, _p-_m); \
     } while (0)
 
@@ -794,8 +779,8 @@ print_cb_help(void)
 /* time */
 #define DPFT(T, name, var) \
     do { \
-        char * last; \
-        printf(T "%s = \"%s\"\n", name, strtok_r(ctime(&(var)), "\r\n", &last)); \
+        time_t t = var; \
+        printf(T "%s = \"%.24s\"\n", name, ctime(&t)); \
     } while(0)
 #define DPFT1(name, var) DPFT(DPFTB1, name, var)
 #define DPFT2(name, var) DPFT(DPFTB2, name, var)
@@ -1356,7 +1341,6 @@ dump_he_interfaces(void)
 static void
 dump_he_hcps(void)
 {
-    char temp_str[40];
     afs_int32 * hcps;
     int len, i;
 
@@ -1444,14 +1428,13 @@ hexdump_map(afs_uint32 offset, afs_uint32 len)
 {
     int i;
     unsigned char * p = (unsigned char *)map;
-    afs_uint32 c32;
 
     if (!len)
 	return;
 
     if ((offset + len) > map_len) {
-	fprintf(stderr, "offset + length exceeds memory map size (%u > %u)\n",
-		offset+len, map_len);
+	fprintf(stderr, "offset + length exceeds memory map size (%u > %lu)\n",
+		offset+len, (unsigned long)map_len);
 	return;
     }
 
@@ -1615,8 +1598,6 @@ get_cb_timeout_hdr(void)
 static int
 get_cb_timeout(void)
 {
-    char * buf;
-
     if (hdrs.timeout)
 	return 0;
 
@@ -1668,8 +1649,6 @@ get_cb_fehash_hdr(void)
 static int
 get_cb_fehash(void)
 {
-    char * buf;
-
     if (hdrs.fehash)
 	return 0;
 
@@ -1835,6 +1814,12 @@ get_fe(afs_uint32 idx)
 static int
 get_fe_hdr(void)
 {
+    if (!fe_cursor.cursor) {
+        if(get_fe(fe_cursor.idx)) {
+	    return 1;
+        }
+    }
+    
     memcpy(&fe_cursor.hdr, fe_cursor.cursor, sizeof(struct callback_state_entry_header));
     fe_cursor.hdr_valid = 1;
     return 0;
@@ -1865,7 +1850,6 @@ get_fe_entry(void)
 static int
 get_cb(afs_uint32 idx)
 {
-    int i;
     char * p;
 
     if (get_fe(fe_cursor.idx))
@@ -1899,6 +1883,7 @@ get_cb_entry(void)
     return 0;
 }
 
+#if 0
 static int
 find_he_by_index(afs_uint32 idx)
 {
@@ -1923,6 +1908,7 @@ find_he_by_index(afs_uint32 idx)
     }
     return 1;
 }
+#endif
 
 static int
 find_fe_by_index(afs_uint32 idx)
