@@ -14,6 +14,9 @@
 #include <afs/param.h>
 #endif
 
+#ifdef IGNORE_SOME_GCC_WARNINGS
+# pragma GCC diagnostic warning "-Wstrict-prototypes"
+#endif
 
 #if defined(UKERNEL)
 #include "afs/sysincludes.h"
@@ -150,8 +153,10 @@ afs_random(void)
 #ifdef AFS_PTHREAD_ENV
     afs_uint32 state;
 
-    (called_afs_random_once || pthread_once(&random_once, afs_random_once));
-    state = (afs_uint32) pthread_getspecific(random_number_key);
+    if (!called_afs_random_once)
+	pthread_once(&random_once, afs_random_once);
+
+    state = (uintptr_t) pthread_getspecific(random_number_key);
 #else
     static afs_uint32 state = 0;
 #endif
@@ -166,7 +171,7 @@ afs_random(void)
 
     ranstage(state);
 #ifdef AFS_PTHREAD_ENV
-    pthread_setspecific(random_number_key, (const void *)state);
+    pthread_setspecific(random_number_key, (const void *)(uintptr_t)state);
 #endif
     return (state);
 
