@@ -21,8 +21,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/viced/viced.c,v 1.75.2.33 2009/03/24 03:44:14 shadow Exp $");
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -70,6 +68,7 @@ RCSID
 #include <afs/acl.h>
 #include <afs/prs_fs.h>
 #include <rx/rx.h>
+#include <rx/rxstat.h>
 #include <afs/keys.h>
 #include <afs/afs_args.h>
 #include <afs/vlserver.h>
@@ -78,6 +77,7 @@ RCSID
 #include <afs/ptuser.h>
 #include <afs/audit.h>
 #include <afs/partition.h>
+#include <afs/dir.h>
 #ifndef AFS_NT40_ENV
 #include <afs/netutils.h>
 #endif
@@ -105,20 +105,17 @@ RCSID
 #define afs_fopen	fopen
 #endif /* !O_LARGEFILE */
 
-extern int BreakVolumeCallBacks(), InitCallBack();
-extern int BreakVolumeCallBacks(), InitCallBack(), BreakLaterCallBacks();
-extern int BreakVolumeCallBacksLater();
-extern int LogLevel, etext;
-extern afs_int32 BlocksSpare, PctSpare;
+extern int etext;
 
 void *ShutDown(void *);
-static void ClearXStatValues(), NewParms(), PrintCounters();
-static void ResetCheckDescriptors(void), ResetCheckSignal(void);
+static void ClearXStatValues(void);
+static void NewParms(int);
+static void PrintCounters(void);
+static void ResetCheckDescriptors(void);
+static void ResetCheckSignal(void);
 static void *CheckSignal(void *);
-extern int GetKeysFromToken();
-extern int RXAFS_ExecuteRequest();
-extern int RXSTATS_ExecuteRequest();
-afs_int32 Do_VLRegisterRPC();
+
+static afs_int32 Do_VLRegisterRPC(void);
 
 int eventlog = 0, rxlog = 0;
 FILE *debugFile;
@@ -200,6 +197,10 @@ struct timeval tp;
 pthread_key_t viced_uclient_key;
 #endif
 
+#ifdef AFS_PTHREAD_ENV
+pthread_key_t viced_uclient_key;
+#endif
+
 /*
  * FileServer's name and IP address, both network byte order and
  * host byte order.
@@ -213,7 +214,7 @@ afs_uint32 FS_HostAddrs[ADDRSPERSITE], FS_HostAddr_cnt = 0, FS_registered = 0;
 /* All addresses in FS_HostAddrs are in NBO */
 afsUUID FS_HostUUID;
 
-static void FlagMsg();
+static void FlagMsg(void);
 
 #ifdef AFS_DEMAND_ATTACH_FS
 /*
@@ -270,37 +271,37 @@ CheckDescriptors(void *unused)
 
 #ifdef AFS_PTHREAD_ENV
 void
-CheckSignal_Signal(x)
+CheckSignal_Signal(int x)
 {
     CheckSignal(NULL);
 }
 
 void
-ShutDown_Signal(x)
+ShutDown_Signal(int x)
 {
     ShutDown(NULL);
 }
 
 void
-CheckDescriptors_Signal(x)
+CheckDescriptors_Signal(int x)
 {
     CheckDescriptors(NULL);
 }
 #else /* AFS_PTHREAD_ENV */
 void
-CheckSignal_Signal(x)
+CheckSignal_Signal(int x)
 {
     IOMGR_SoftSig(CheckSignal, 0);
 }
 
 void
-ShutDown_Signal(x)
+ShutDown_Signal(int x)
 {
     IOMGR_SoftSig(ShutDown, 0);
 }
 
 void
-CheckDescriptors_Signal(x)
+CheckDescriptors_Signal(int x)
 {
     IOMGR_SoftSig(CheckDescriptors, 0);
 }
@@ -351,7 +352,7 @@ ResetCheckDescriptors(void)
 int
 threadNum(void)
 {
-    return (int)pthread_getspecific(rx_thread_id_key);
+    return (intptr_t)pthread_getspecific(rx_thread_id_key);
 }
 #endif
 
@@ -374,7 +375,6 @@ get_key(void *arock, register afs_int32 akvno, struct ktc_encryptionKey *akey)
     }
     memcpy(akey, tkey.key, sizeof(tkey.key));
     return 0;
-
 }				/*get_key */
 
 #ifndef AFS_NT40_ENV
@@ -382,10 +382,10 @@ int
 viced_syscall(afs_uint32 a3, afs_uint32 a4, void *a5)
 {
     afs_uint32 rcode;
-    void (*old) ();
-
 #ifndef AFS_LINUX20_ENV
-    old = (void (*)())signal(SIGSYS, SIG_IGN);
+    void (*old) (int);
+
+    old = (void (*)(int))signal(SIGSYS, SIG_IGN);
 #endif
     rcode = syscall(AFS_SYSCALL, 28 /* AFSCALL_CALL */ , a3, a4, a5);
 #ifndef AFS_LINUX20_ENV
@@ -404,7 +404,7 @@ viced_syscall(afs_uint32 a3, afs_uint32 a4, void *a5)
 char adminName[MAXADMINNAME];
 
 static void
-CheckAdminName()
+CheckAdminName(void)
 {
     int fd = 0;
     struct afs_stat status;
@@ -430,7 +430,7 @@ setThreadId(char *s)
     /* set our 'thread-id' so that the host hold table works */
     MUTEX_ENTER(&rx_stats_mutex);	/* protects rxi_pthread_hinum */
     ++rxi_pthread_hinum;
-    pthread_setspecific(rx_thread_id_key, (void *)rxi_pthread_hinum);
+    pthread_setspecific(rx_thread_id_key, (void *)(intptr_t)rxi_pthread_hinum);
     MUTEX_EXIT(&rx_stats_mutex);
     ViceLog(0,
 	    ("Set thread id %d for '%s'\n",
@@ -651,7 +651,7 @@ FsyncCheckLWP(void *unused)
  *------------------------------------------------------------------------*/
 
 static void
-ClearXStatValues()
+ClearXStatValues(void)
 {				/*ClearXStatValues */
 
     struct fs_stats_opTimingData *opTimeP;	/*Ptr to timing struct */
@@ -702,7 +702,7 @@ int CopyOnWrite_calls = 0, CopyOnWrite_off0 = 0, CopyOnWrite_size0 = 0;
 afs_fsize_t CopyOnWrite_maxsize = 0;
 
 static void
-PrintCounters()
+PrintCounters(void)
 {
     int dirbuff, dircall, dirio;
     struct timeval tpl;
@@ -728,6 +728,7 @@ PrintCounters()
 	    ("With %d directory buffers; %d reads resulted in %d read I/Os\n",
 	     dirbuff, dircall, dirio));
     rx_PrintStats(stderr);
+    audit_PrintStats(stderr);
     h_PrintStats();
     PrintCallBackStats();
 #ifdef AFS_NT40_ENV
@@ -869,74 +870,71 @@ ShutDown(void *unused)
 
 
 static void
-FlagMsg()
+FlagMsg(void)
 {
-    char buffer[2048];
-
     /* default supports help flag */
 
-    strcpy(buffer, "Usage: fileserver ");
-    strcpy(buffer, "[-auditlog <log path>] ");
-    strcat(buffer, "[-d <debug level>] ");
-    strcat(buffer, "[-p <number of processes>] ");
-    strcat(buffer, "[-spare <number of spare blocks>] ");
-    strcat(buffer, "[-pctspare <percentage spare>] ");
-    strcat(buffer, "[-b <buffers>] ");
-    strcat(buffer, "[-l <large vnodes>] ");
-    strcat(buffer, "[-s <small vnodes>] ");
-    strcat(buffer, "[-vc <volume cachesize>] ");
-    strcat(buffer, "[-w <call back wait interval>] ");
-    strcat(buffer, "[-cb <number of call backs>] ");
-    strcat(buffer, "[-banner (print banner every 10 minutes)] ");
-    strcat(buffer, "[-novbc (whole volume cbs disabled)] ");
-    strcat(buffer, "[-implicit <admin mode bits: rlidwka>] ");
-    strcat(buffer, "[-readonly (read-only file server)] ");
-    strcat(buffer,
-	   "[-hr <number of hours between refreshing the host cps>] ");
-    strcat(buffer, "[-busyat <redirect clients when queue > n>] ");
-    strcat(buffer, "[-nobusy <no VBUSY before a volume is attached>] ");
-    strcat(buffer, "[-rxpck <number of rx extra packets>] ");
-    strcat(buffer, "[-rxdbg (enable rx debugging)] ");
-    strcat(buffer, "[-rxdbge (enable rxevent debugging)] ");
-    strcat(buffer, "[-rxmaxmtu <bytes>] ");
-    strcat(buffer, "[-rxbind (bind the Rx socket to one address)] ");
-    strcat(buffer, "[-allow-dotted-principals (disable the rxkad principal name dot check)] ");
+    fputs("Usage: fileserver ", stdout);
+    fputs("[-auditlog <log path>] ", stdout);
+    fputs("[-audit-interface <file|sysvmq> (default is file)] ", stdout);
+    fputs("[-d <debug level>] ", stdout);
+    fputs("[-p <number of processes>] ", stdout);
+    fputs("[-spare <number of spare blocks>] ", stdout);
+    fputs("[-pctspare <percentage spare>] ", stdout);
+    fputs("[-b <buffers>] ", stdout);
+    fputs("[-l <large vnodes>] ", stdout);
+    fputs("[-s <small vnodes>] ", stdout);
+    fputs("[-vc <volume cachesize>] ", stdout);
+    fputs("[-w <call back wait interval>] ", stdout);
+    fputs("[-cb <number of call backs>] ", stdout);
+    fputs("[-banner (print banner every 10 minutes)] ", stdout);
+    fputs("[-novbc (whole volume cbs disabled)] ", stdout);
+    fputs("[-implicit <admin mode bits: rlidwka>] ", stdout);
+    fputs("[-readonly (read-only file server)] ", stdout);
+    fputs("[-hr <number of hours between refreshing the host cps>] ", stdout);
+    fputs("[-busyat <redirect clients when queue > n>] ", stdout);
+    fputs("[-nobusy <no VBUSY before a volume is attached>] ", stdout);
+    fputs("[-rxpck <number of rx extra packets>] ", stdout);
+    fputs("[-rxdbg (enable rx debugging)] ", stdout);
+    fputs("[-rxdbge (enable rxevent debugging)] ", stdout);
+    fputs("[-rxmaxmtu <bytes>] ", stdout);
+    fputs("[-rxbind (bind the Rx socket to one address)] ", stdout);
+    fputs("[-allow-dotted-principals (disable the rxkad principal name dot check)] ", stdout);
 #ifdef AFS_DEMAND_ATTACH_FS
-    strcat(buffer, "[-fs-state-dont-save (disable state save during shutdown)] ");
-    strcat(buffer, "[-fs-state-dont-restore (disable state restore during startup)] ");
-    strcat(buffer, "[-fs-state-verify <none|save|restore|both> (default is both)] ");
-    strcat(buffer, "[-vattachpar <max number of volume attach/shutdown threads> (default is 1)] ");
-    strcat(buffer, "[-vhashsize <log(2) of number of volume hash buckets> (default is 8)] ");
-    strcat(buffer, "[-vlrudisable (disable VLRU functionality)] ");
-    strcat(buffer, "[-vlruthresh <minutes before unused volumes become eligible for soft detach> (default is 2 hours)] ");
-    strcat(buffer, "[-vlruinterval <seconds between VLRU scans> (default is 2 minutes)] ");
-    strcat(buffer, "[-vlrumax <max volumes to soft detach in one VLRU scan> (default is 8)] ");
+    fputs("[-fs-state-dont-save (disable state save during shutdown)] ", stdout);
+    fputs("[-fs-state-dont-restore (disable state restore during startup)] ", stdout);
+    fputs("[-fs-state-verify <none|save|restore|both> (default is both)] ", stdout);
+    fputs("[-vattachpar <max number of volume attach/shutdown threads> (default is 1)] ", stdout);
+    fputs("[-vhashsize <log(2) of number of volume hash buckets> (default is 8)] ", stdout);
+    fputs("[-vlrudisable (disable VLRU functionality)] ", stdout);
+    fputs("[-vlruthresh <minutes before unused volumes become eligible for soft detach> (default is 2 hours)] ", stdout);
+    fputs("[-vlruinterval <seconds between VLRU scans> (default is 2 minutes)] ", stdout);
+    fputs("[-vlrumax <max volumes to soft detach in one VLRU scan> (default is 8)] ", stdout);
 #elif AFS_PTHREAD_ENV
-    strcat(buffer, "[-vattachpar <number of volume attach threads> (default is 1)] ");
+    fputs("[-vattachpar <number of volume attach threads> (default is 1)] ", stdout);
 #endif
 #ifdef	AFS_AIX32_ENV
-    strcat(buffer, "[-m <min percentage spare in partition>] ");
+    fputs("[-m <min percentage spare in partition>] ", stdout);
 #endif
 #if defined(AFS_SGI_ENV)
-    strcat(buffer, "[-lock (keep fileserver from swapping)] ");
+    fputs("[-lock (keep fileserver from swapping)] ", stdout);
 #endif
-    strcat(buffer, "[-L (large server conf)] ");
-    strcat(buffer, "[-S (small server conf)] ");
-    strcat(buffer, "[-k <stack size>] ");
-    strcat(buffer, "[-realm <Kerberos realm name>] ");
-    strcat(buffer, "[-udpsize <size of socket buffer in bytes>] ");
-    strcat(buffer, "[-sendsize <size of send buffer in bytes>] ");
-    strcat(buffer, "[-abortthreshold <abort threshold>] ");
-    strcat(buffer, "[-nojumbo (disable jumbogram network packets - deprecated)] ");
-    strcat(buffer, "[-jumbo (enable jumbogram network packets)] ");
-/*   strcat(buffer, "[-enable_peer_stats] "); */
-/*   strcat(buffer, "[-enable_process_stats] "); */
-    strcat(buffer, "[-help]\n");
+    fputs("[-L (large server conf)] ", stdout);
+    fputs("[-S (small server conf)] ", stdout);
+    fputs("[-k <stack size>] ", stdout);
+    fputs("[-realm <Kerberos realm name>] ", stdout);
+    fputs("[-udpsize <size of socket buffer in bytes>] ", stdout);
+    fputs("[-sendsize <size of send buffer in bytes>] ", stdout);
+    fputs("[-abortthreshold <abort threshold>] ", stdout);
+    fputs("[-nojumbo (disable jumbogram network packets - deprecated)] ", stdout);
+    fputs("[-jumbo (enable jumbogram network packets)] ", stdout);
+/*   fputs("[-enable_peer_stats] ", stdout); */
+/*   fputs("[-enable_process_stats] ", stdout); */
+    fputs("[-help]\n", stdout);
 /*
     ViceLog(0, ("%s", buffer));
 */
 
-    printf("%s", buffer);
     fflush(stdout);
 
 }				/*FlagMsg */
@@ -1044,6 +1042,7 @@ ParseArgs(int argc, char *argv[])
     int Sawbusy = 0;
     int i;
     int bufSize = 0;		/* temp variable to read in udp socket buf size */
+    char *auditFileName = NULL;
 
     for (i = 1; i < argc; i++) {
 	if (!strcmp(argv[i], "-d")) {
@@ -1294,7 +1293,7 @@ ParseArgs(int argc, char *argv[])
 	    rxMaxMTU = atoi(argv[++i]);
 	    if ((rxMaxMTU < RX_MIN_PACKET_SIZE) || 
 		(rxMaxMTU > RX_MAX_PACKET_DATA_SIZE)) {
-		printf("rxMaxMTU %d%% invalid; must be between %d-%d\n",
+		printf("rxMaxMTU %d%% invalid; must be between %d-%lu\n",
 		       rxMaxMTU, RX_MIN_PACKET_SIZE, 
 		       RX_MAX_PACKET_DATA_SIZE);
 		return -1;
@@ -1351,9 +1350,15 @@ ParseArgs(int argc, char *argv[])
 	    rx_enableProcessRPCStats();
 	}
 	else if (strcmp(argv[i], "-auditlog") == 0) {
-	    char *fileName = argv[++i];
+	    auditFileName = argv[++i];
+	}
+	else if (strcmp(argv[i], "-audit-interface") == 0) {
+	    char *interface = argv[++i];
 
-            osi_audit_file(fileName);
+	    if (osi_audit_interface(interface)) {
+		printf("Invalid audit interface '%s'\n", interface);
+		return -1;
+	    }
 	}
 #ifndef AFS_NT40_ENV
 	else if (strcmp(argv[i], "-syslog") == 0) {
@@ -1413,6 +1418,8 @@ ParseArgs(int argc, char *argv[])
     }
     if (!Sawbusy)
 	busy_threshold = 3 * rxpackets / 2;
+    if (auditFileName)
+	osi_audit_file(auditFileName);
 
     return (0);
 
@@ -1499,7 +1506,7 @@ Die(char *msg)
 
 
 afs_int32
-InitPR()
+InitPR(void)
 {
     int code;
 
@@ -1597,7 +1604,7 @@ vl_Initialize(const char *confDir)
 #define SYSIDVERSION	1
 
 afs_int32
-ReadSysIdFile()
+ReadSysIdFile(void)
 {
     afs_int32 fd, nentries, i;
     struct versionStamp vsn;
@@ -1679,7 +1686,7 @@ ReadSysIdFile()
 }
 
 afs_int32
-WriteSysIdFile()
+WriteSysIdFile(void)
 {
     afs_int32 fd, i;
     struct versionStamp vsn;
@@ -1747,12 +1754,11 @@ WriteSysIdFile()
  * and so we need to convert each of them into HBO which is what the extra 
  * array called FS_HostAddrs_HBO is used here.
  */
-afs_int32
-Do_VLRegisterRPC()
+static afs_int32
+Do_VLRegisterRPC(void)
 {
     register int code;
     bulkaddrs addrs;
-    extern int VL_RegisterAddrs();
     afs_uint32 FS_HostAddrs_HBO[ADDRSPERSITE];
     int i = 0;
 
@@ -1776,6 +1782,7 @@ Do_VLRegisterRPC()
 	    ViceLog(0,
 		    ("VL_RegisterAddrs rpc failed; will retry periodically (code=%d, err=%d)\n",
 		     code, errno));
+	    FS_registered = 1;	/* Retry in the gc daemon */
 	}
     } else {
 	FS_registered = 2;	/* So we don't have to retry in the gc daemon */
@@ -1786,11 +1793,9 @@ Do_VLRegisterRPC()
 }
 
 afs_int32
-SetupVL()
+SetupVL(void)
 {
     afs_int32 code;
-    extern int rxi_numNetAddrs;
-    extern afs_uint32 rxi_NetAddrs[];
 
     if (AFSDIR_SERVER_NETRESTRICT_FILEPATH || AFSDIR_SERVER_NETINFO_FILEPATH) {
 	/*
@@ -1821,7 +1826,7 @@ SetupVL()
 }
 
 afs_int32
-InitVL()
+InitVL(void)
 {
     afs_int32 code;
 
@@ -2032,12 +2037,16 @@ main(int argc, char *argv[])
     rx_SetBusyThreshold(busy_threshold, VBUSY);
     rx_SetCallAbortThreshold(abort_threshold);
     rx_SetConnAbortThreshold(abort_threshold);
+#ifdef AFS_XBSD_ENV
+    stackSize = 128 * 1024;
+#else
     stackSize = lwps * 4000;
     if (stackSize < 32000)
 	stackSize = 32000;
     else if (stackSize > 44000)
 	stackSize = 44000;
-#if    defined(AFS_HPUX_ENV) || defined(AFS_SUN_ENV) || defined(AFS_SGI51_ENV)
+#endif
+#if defined(AFS_HPUX_ENV) || defined(AFS_SUN_ENV) || defined(AFS_SGI51_ENV) || defined(AFS_XBSD_ENV)
     rx_SetStackSize(1, stackSize);
 #endif
     if (udpBufSize)
@@ -2113,13 +2122,13 @@ main(int argc, char *argv[])
     ClearXStatValues();
 
     code = InitVL();
-    if (code) {
+    if (code && code != VL_MULTIPADDR) {
 	ViceLog(0, ("Fatal error in library initialization, exiting!!\n"));
 	exit(1);
     }
 
     code = InitPR();
-    if (code) {
+    if (code && code != -1) {
 	ViceLog(0, ("Fatal error in protection initialization, exiting!!\n"));
 	exit(1);
     }
