@@ -237,7 +237,7 @@ FSYNC_sync(void * args)
     MUTEX_ENTER(&rx_stats_mutex);	/* protects rxi_pthread_hinum */
     tid = ++rxi_pthread_hinum;
     MUTEX_EXIT(&rx_stats_mutex);
-    pthread_setspecific(rx_thread_id_key, (void *)tid);
+    pthread_setspecific(rx_thread_id_key, (void *)(intptr_t)tid);
     Log("Set thread id %d for FSYNC_sync\n", tid);
 #endif /* AFS_PTHREAD_ENV */
 
@@ -360,7 +360,10 @@ FSYNC_com(osi_socket fd)
     if (com.hdr.command == SYNC_COM_CHANNEL_CLOSE) {
 	res.hdr.response = SYNC_OK;
 	res.hdr.flags |= SYNC_FLAG_CHANNEL_SHUTDOWN;
-	goto respond;
+
+	/* don't respond, just drop; senders of SYNC_COM_CHANNEL_CLOSE
+	 * never wait for a response. */
+	goto done;
     }
 
     res.hdr.com_seq = com.hdr.com_seq;
@@ -400,6 +403,8 @@ FSYNC_com(osi_socket fd)
 
  respond:
     SYNC_putRes(&fssync_server_state, fd, &res);
+
+ done:
     if (res.hdr.flags & SYNC_FLAG_CHANNEL_SHUTDOWN) {
 	FSYNC_Drop(fd);
     }
@@ -503,7 +508,9 @@ static afs_int32
 FSYNC_com_VolOn(FSSYNC_VolOp_command * vcom, SYNC_response * res)
 {
     afs_int32 code = SYNC_OK;
+#ifndef AFS_DEMAND_ATTACH_FS
     char tvolName[VMAXPATHLEN];
+#endif
     Volume * vp;
     Error error;
 
@@ -625,7 +632,6 @@ FSYNC_com_VolOff(FSSYNC_VolOp_command * vcom, SYNC_response * res)
     Volume * vp;
     Error error;
 #ifdef AFS_DEMAND_ATTACH_FS
-    int reserved = 0;
     Volume *nvp;
 #endif
 
@@ -900,7 +906,9 @@ FSYNC_com_VolMove(FSSYNC_VolOp_command * vcom, SYNC_response * res)
 	} else {
 	    res->hdr.reason = FSYNC_WRONG_PART;
 	}
+#ifndef AFS_DEMAND_ATTACH_FS
 	VPutVolume_r(vp);
+#endif /* !AFS_DEMAND_ATTACH_FS */
     } else {
 	res->hdr.reason = FSYNC_UNKNOWN_VOLID;
     }
@@ -1183,17 +1191,17 @@ FSYNC_com_VolHdrQuery(FSSYNC_VolOp_command * vcom, SYNC_response * res)
 		!(V_attachFlags(vp) & VOL_HDR_ATTACHED) ||
 		!(V_attachFlags(vp) & VOL_HDR_LOADED)) {
 		res->hdr.reason = FSYNC_HDR_NOT_ATTACHED;
-		goto done;
+		goto cleanup;
 	    }
 #else /* !AFS_DEMAND_ATTACH_FS */
 	    if (!vp || !vp->header) {
 		res->hdr.reason = FSYNC_HDR_NOT_ATTACHED;
-		goto done;
+		goto cleanup;
 	    }
 #endif /* !AFS_DEMAND_ATTACH_FS */
 	} else {
 	    res->hdr.reason = FSYNC_WRONG_PART;
-	    goto done;
+	    goto cleanup;
 	}
     } else {
 	res->hdr.reason = FSYNC_UNKNOWN_VOLID;
@@ -1202,10 +1210,12 @@ FSYNC_com_VolHdrQuery(FSSYNC_VolOp_command * vcom, SYNC_response * res)
 
     memcpy(res->payload.buf, &V_disk(vp), sizeof(VolumeDiskData));
     res->hdr.response_len += sizeof(VolumeDiskData);
+    code = SYNC_OK;
+
+ cleanup:
 #ifndef AFS_DEMAND_ATTACH_FS
     VPutVolume_r(vp);
 #endif
-    code = SYNC_OK;
 
  done:
     return code;
