@@ -28,8 +28,9 @@ VIsSalvager(ProgramType type)
     case salvager:
     case salvageServer:
 	return 1;
+    default:
+	return 0;
     }
-    return 0;
 }
 
 /***************************************************/
@@ -65,9 +66,11 @@ VIsExclusiveState(VolState state)
     case VOL_STATE_VNODE_GET:
     case VOL_STATE_VNODE_CLOSE:
     case VOL_STATE_VNODE_RELEASE:
+    case VOL_STATE_VLRU_ADD:
 	return 1;
+    default:
+	return 0;
     }
-    return 0;
 }
 
 /**
@@ -88,8 +91,9 @@ VIsErrorState(VolState state)
     case VOL_STATE_ERROR:
     case VOL_STATE_SALVAGING:
 	return 1;
+    default:
+	return 0;
     }
-    return 0;
 }
 
 /**
@@ -111,8 +115,9 @@ VIsOfflineState(VolState state)
     case VOL_STATE_ERROR:
     case VOL_STATE_SALVAGING:
 	return 1;
+    default:
+	return 0;
     }
-    return 0;
 }
 
 /**
