@@ -8,7 +8,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-#ifdef AFS_NAMEI_ENV
+#if defined(AFS_NAMEI_ENV) && !defined(AFS_NT40_ENV)
 #include <sys/types.h>
 #include <stdio.h>
 #ifdef AFS_PTHREAD_ENV
@@ -25,6 +25,7 @@
 #else
 #include <sys/file.h>
 #include <sys/time.h>
+#include <unistd.h>
 #endif
 #ifdef HAVE_STRING_H
 #include <string.h>
@@ -36,6 +37,7 @@
 #include <errno.h>
 #include <sys/stat.h>
 
+#include <afs/dir.h>
 #include <rx/xdr.h>
 #include <afs/afsint.h>
 #include "nfs.h"
@@ -48,6 +50,10 @@
 #include "partition.h"
 #include "viceinode.h"
 #include "vol.h"
+#include "volint.h"
+#include "volser.h"
+#include "physio.h"
+#include "volser_prototypes.h"
 #ifdef AFS_RXOSD_SUPPORT
 #include "rxosd.h"
 #include "vol_osd.h"
@@ -79,9 +85,9 @@ struct Msg {
 static afs_int32 
 ExtractVnodes(struct Msg *m, Volume *vol, afs_int32 class, 
 	      struct VnodeExtract **list,
-	      afs_int32 *length, afs_uint32 where, 
+	      afs_uint32 *length, afs_uint32 where,
 	      struct VnodeDiskObject *vd,
-	      afs_int32 *parent, struct VnodeDiskObject *parentvd)
+	      afs_uint32 *parent, struct VnodeDiskObject *parentvd)
 {
     afs_int32 code = 0;
     char buf[SIZEOF_LARGEDISKVNODE];
@@ -92,7 +98,6 @@ ExtractVnodes(struct Msg *m, Volume *vol, afs_int32 class,
     struct VnodeExtract *e;
     afs_uint32 size;
     afs_uint32 offset;
-    afs_uint32 vN; 
 
     *length = 0;
     if (parent)
@@ -159,8 +164,9 @@ ExtractVnodes(struct Msg *m, Volume *vol, afs_int32 class,
 	}
     }
     if (m->verbose) {
-	sprintf(m->line, "Volume %u has %u %s vnodes in volume %uu\n", 
-			V_parentId(vol), *length, class? "small":"large");
+	sprintf(m->line, "Volume %u has %u %s vnodes in volume %u\n",
+			V_parentId(vol), *length, class? "small":"large",
+			V_id(vol));
 	rx_Write(m->call, m->line, strlen(m->line));
     }
     
@@ -180,7 +186,7 @@ static afs_int32
 FindVnodes(struct Msg *m, afs_uint32 where, 
 	   struct VnodeExtract *list, afs_int32 length, 
 	   struct VnodeExtract *dlist, afs_int32 dlength, 
-	   afs_int32 *needed, afs_int32 class)
+	   afs_uint32 *needed, afs_int32 class)
 {
     afs_int32 i, j, found = 0;
     afs_int32 parent = 0;
@@ -247,7 +253,6 @@ FindVnodes(struct Msg *m, afs_uint32 where,
 static afs_int32 
 copyDir(struct Msg *m, IHandle_t *inh, IHandle_t *outh)
 {
-    afs_int32 code;
     FdHandle_t *infdP, *outfdP;
     char *tbuf;
     afs_size_t size;
@@ -319,13 +324,11 @@ afs_int32 copyVnodes(struct Msg *m, Volume *vol, Volume *newvol,
     struct VnodeDiskObject *vnode = (struct VnodeDiskObject *)&buf;
     FdHandle_t *fdP = 0;
     FdHandle_t *newfdP = 0;
-    StreamHandle_t *newstream = 0;
     struct VnodeClassInfo *vcp = &VnodeClassInfo[class];
     struct VnodeExtract *e;
     afs_uint64 size;
     afs_uint64 offset;
     Inode ino, newino;
-    afs_uint32 newVn;
 
     fdP = IH_OPEN(vol->vnodeIndex[class].handle);
     if (!fdP) {
@@ -361,11 +364,8 @@ afs_int32 copyVnodes(struct Msg *m, Volume *vol, Volume *newvol,
                  */ 
 		IHandle_t *newh = 0;
 		IHandle_t *h = 0;
-		FdHandle_t *infdP = 0;
-		FdHandle_t *outfdP = 0;
-		char *tbuf = malloc(2048);
+#if defined(NEARINODE_HINT) && !defined(AFS_NAMEI_ENV)
 		Inode nearInode;
-#if defined(NEARINODE_HINT)
 		V_pref(vol,nearInode)
 #endif
 
@@ -399,7 +399,7 @@ afs_int32 copyVnodes(struct Msg *m, Volume *vol, Volume *newvol,
 	        if (ino) {
 		    IHandle_t *h, *newh;
 		    Inode nearInode;
-#if defined(NEARINODE_HINT)
+#if defined(NEARINODE_HINT) && !defined(AFS_NAMEI_ENV)
 		    V_pref(vol,nearInode)
 #endif
 	            IH_INIT(h, vol->device, V_parentId(vol), ino);
@@ -528,13 +528,15 @@ createMountpoint(Volume *vol, Volume *newvol, struct VnodeDiskObject *parent,
     afs_uint64 offset, size;
     afs_int32 class = vSmall;
     struct VnodeClassInfo *vcp = &VnodeClassInfo[class];
+#if defined(NEARINODE_HINT) && !defined(AFS_NAMEI_ENV)
     Inode nearInode = 0;
+#endif
     AFSFid fid;
     struct timeval now;
     afs_uint32 newvN;
     char symlink[32];
 
-    TM_GetTimeOfDay(&now, 0);
+    FT_GetTimeOfDay(&now, 0);
     fdP = IH_OPEN(vol->vnodeIndex[vSmall].handle);
     if (!fdP) {
 	Log("split volume: error opening small vnode index of %u\n", V_id(vol));
@@ -567,7 +569,7 @@ createMountpoint(Volume *vol, Volume *newvol, struct VnodeDiskObject *parent,
     vnode.parent = vN;
 
     newvN = (offset >> (VnodeClassInfo[class].logSize - 1)) - 1 + class;
-#if defined(NEARINODE_HINT)
+#if defined(NEARINODE_HINT) && !defined(AFS_NAMEI_ENV)
     V_pref(vol,nearInode)
 #endif
     newino = IH_CREATE(V_linkHandle(vol), V_device(vol),
@@ -582,9 +584,9 @@ createMountpoint(Volume *vol, Volume *newvol, struct VnodeDiskObject *parent,
 	return EIO;
     }
     FDH_SEEK(fdP2, 0, 0);
-    sprintf(&symlink, "#%s", V_name(newvol));
+    sprintf(symlink, "#%s", V_name(newvol));
     size = strlen(symlink) + 1;
-    if (FDH_WRITE(fdP2, &symlink, size) != size) {
+    if (FDH_WRITE(fdP2, symlink, size) != size) {
 	Log("split volume: couldn't write mountpoint %u.%u.%u\n", 
 		V_id(vol), newvN, vnode.uniquifier);
 	return EIO;
@@ -684,7 +686,7 @@ deleteVnodes(Volume *vol, afs_int32 class,
 	    *blocks += (size + 0x3ff) >> 10;
 	    ino = VNDISK_GET_INO(vnode);
 	    if (ino) {
-		IHandle_t *h, *newh;
+		IHandle_t *h;
 	        IH_INIT(h, vol->device, V_parentId(vol), ino);
 		    IH_DEC(h, ino, V_parentId(vol));
 #ifdef AFS_RXOSD_SUPPORT
@@ -712,7 +714,7 @@ afs_int32
 split_volume(struct rx_call *call, Volume *vol, Volume *newvol, 
 	     afs_uint32 where, afs_int32 verbose)
 {
-    afs_int32 code = 0;
+    Error code = 0;
     struct VnodeExtract *dirList = 0;
     struct VnodeExtract *fileList = 0;
     afs_uint64 blocks = 0;
@@ -759,7 +761,7 @@ split_volume(struct rx_call *call, Volume *vol, Volume *newvol,
 	rx_Write(m->call, m->line, strlen(m->line));
     }
     code = findName(vol, parVnode, where, rootVnode->uniquifier, 
-			&name,  sizeof(name));
+                    name,  sizeof(name));
     if (code) {
 	sprintf(m->line, 
 		"splitvolume: could'nt find name of %u in directory %u.%u.%u.\n",
