@@ -102,7 +102,7 @@ afs_uint32 SHostAddrs[ADDRSPERSITE];
 int
 threadNum(void)
 {
-    return (int)pthread_getspecific(rx_thread_id_key);
+    return (intptr_t)pthread_getspecific(rx_thread_id_key);
 }
 #endif
 
@@ -169,6 +169,7 @@ BKGLoop(void *unused)
 
 /* Background daemon for sleeping so the volserver does not become I/O bound */
 afs_int32 TTsleep, TTrun;
+#ifndef AFS_PTHREAD_ENV
 static void *
 BKGSleep(void *unused)
 {
@@ -200,6 +201,7 @@ BKGSleep(void *unused)
     }
     return NULL;
 }
+#endif
 
 #ifndef AFS_NT40_ENV
 int
